
###############
# Initial data procesing
###############
library(MetaIntegratorPrivateLupus)
##########
#Download the training data
############
trainingObject <- getGEOData(c("GSE50635", "GSE39088", "GSE8650", "GSE11909", "GSE17755", "GSE22098"))

#Remove GPL97 because it looks at expressed sequence tags
trainingObject$originalData$GSE8650_GPL97 <- NULL
trainingObject$originalData$GSE11909_GPL97 <- NULL

#Give better names to data
names(trainingObject$originalData) <- c("WB...GSE50635", "WB...GSE39088", "PBMC...GSE8650", "PBMC...GSE11909", "PBMC...GSE17755", "WB...GSE22098")

save(trainingObject, file="RData/trainingObject.RData")

##########
#Download the testing data
##########
testingObject <- getGEOData(c("GSE10325", "GSE26975", "GSE27427", "GSE30153", "GSE32591", "GSE37573",  
                              "GSE37356", "GSE38351", "GSE4588", "GSE49454", "GSE51997", "GSE52471",
                              "GSE50772", "GSE61635","GSE78193","GSE72747","GSE72798","GSE55447","GSE13887",
                               "GSE12374","GSE24706","GSE81622","GSE29536","GSE24060","GSE36700",
                               "GSE37426","GSE36941","GSE21649","GSE46923","GSE46920","GSE26950","GSE26949","GSE29938"))

load(paste("RData/pascualGEO.RData", sep=""))
testingObject$originalData$GSE65391 <- pascualGEO$originalData$GSE65391

#Remove the GPL570 for GSE38351 because it only has RA and healthy
testingObject$originalData$GSE38351_GPL570 <- NULL
#Rename the GPL96 for GSE38351 to prevent confusion
testingObject$originalData$GSE38351 <- testingObject$originalData$GSE38351_GPL96
testingObject$originalData$GSE38351_GPL96 <- NULL

testingObject$originalData$GSE46923 <- testingObject$originalData$GSE46923_GPL96
testingObject$originalData$GSE46923_GPL96 <- NULL
testingObject$originalData$GSE46923_GPL97 <- NULL

testingObject$originalData$GSE46920 <- testingObject$originalData$GSE46920_GPL96
testingObject$originalData$GSE46920_GPL96 <- NULL
testingObject$originalData$GSE46920_GPL97 <- NULL

save(testingObject, file="RData/testingObject.RData")


load(file="RData/trainingObject.RData")
load("RData/testingObject.RData")

##############
#Set up some helper functions
##############
subsetOriginalData <- function(originalData, keepMe) {
  originalData$pheno <- originalData$pheno[keepMe, ]
  originalData$expr <- originalData$expr[, keepMe]
  originalData$class <- originalData$class[keepMe]
  print(length(originalData$class))
  return(originalData)
}

classFunction<-function(pheno, column="diseaseState", sleTerms=c("SLE"), healthyTerm="healthy"){
  currGroup<-as.character(pheno[,column])
  
  returnme<-rep(0,length(currGroup))
  names(returnme) <- rownames(pheno)
  #Healthy as 0
  returnme[currGroup==healthyTerm] <- 0
  
  #SLE as 1
  returnme[currGroup %in% sleTerms] <- 1
  return(returnme)
}

##################################
# Clean annotations for training data
##################################

#############
# GSE50635
#################
trainingObject$originalData$WB...GSE50635$formattedName <- "WB - GSE50635"

#Clean up pheno frame
splitFun <- function(curStr) { return(strsplit(as.character(curStr), ": ")[[1]][[2]]) }
trainingObject$originalData$WB...GSE50635$pheno$rbpStatus <- sapply(trainingObject$originalData$WB...GSE50635$pheno$characteristics_ch1.3, splitFun)
trainingObject$originalData$WB...GSE50635$pheno$diseaseState  <- rep("SLE", nrow(trainingObject$originalData$WB...GSE50635$pheno))
trainingObject$originalData$WB...GSE50635$pheno$diseaseState[trainingObject$originalData$WB...GSE50635$pheno$rbpStatus == "Control"] <- "H"

#Set up the class labels
trainingObject$originalData$WB...GSE50635$class <- classFunction(trainingObject$originalData$WB...GSE50635$pheno, sleTerms = c("SLE"), healthyTerm = "H")
trainingObject$originalData$WB...GSE50635$pheno$group <-  trainingObject$originalData$WB...GSE50635$pheno$diseaseState

###############
# GSE39088
###############
trainingObject$originalData$WB...GSE39088$formattedName <- "WB - GSE39088"

#Pheno was messed up, so wrote csv and manually fixed
trainingObject$originalData$WB...GSE39088$pheno <- read.csv(file="prepData/gse39088pheno.csv", row.names = 1)

#Filter out the IFNa stimulated cells
tempPheno <- trainingObject$originalData$WB...GSE39088$pheno[(trainingObject$originalData$WB...GSE39088$pheno$treatment %in% c("none", "Placebo", "IFN-K")),]

#Subset the data
keepMe <- rownames(tempPheno)
trainingObject$originalData$WB...GSE39088 <- subsetOriginalData(trainingObject$originalData$WB...GSE39088, keepMe)

#Label SLE and healthies
trainingObject$originalData$WB...GSE39088$class <- classFunction(trainingObject$originalData$WB...GSE39088$pheno, sleTerms = c("SLE"), healthyTerm = "H")
trainingObject$originalData$WB...GSE39088$pheno$group <-  trainingObject$originalData$WB...GSE39088$pheno$diseaseState

#Pull the complete data into the testing object before splitting
testingObject$originalData$GSE39088...Complete <- trainingObject$originalData$WB...GSE39088
testingObject$originalData$GSE39088...Complete$formattedName <- "WB - GSE39088 - Complete"

#Filter out non time-zero patients
tempPheno <- tempPheno[is.na(tempPheno$time.days) | tempPheno$time.days == 0,]

#Only SLE cases have females, so only keep female controls
tempPheno <- tempPheno[tempPheno$sex == "Female",]

#Subset the data
keepMe <- rownames(tempPheno)
trainingObject$originalData$WB...GSE39088 <- subsetOriginalData(trainingObject$originalData$WB...GSE39088, keepMe)

######################
# GSE8650
######################
trainingObject$originalData$PBMC...GSE8650$formattedName <- "PBMC - GSE8650"


#Clean up the pheno frame
splitFun <- function(curStr) { return(strsplit(as.character(curStr), ": ")[[1]][[2]]) }
trainingObject$originalData$PBMC...GSE8650$pheno$diseaseState <- sapply(trainingObject$originalData$PBMC...GSE8650$pheno$characteristics_ch1.3, splitFun)
trainingObject$originalData$PBMC...GSE8650$pheno$sledai <- sapply(trainingObject$originalData$PBMC...GSE8650$pheno$characteristics_ch1.4, splitFun)
trainingObject$originalData$PBMC...GSE8650$pheno$sledai <- as.integer(gsub("SLEDAI ", "", trainingObject$originalData$PBMC...GSE8650$pheno$sledai))

#Set up the class labels
trainingObject$originalData$PBMC...GSE8650$class <- classFunction(trainingObject$originalData$PBMC...GSE8650$pheno, sleTerms = c("SLE"), healthyTerm = "Healthy")
trainingObject$originalData$PBMC...GSE8650$pheno$group <-  trainingObject$originalData$PBMC...GSE8650$pheno$diseaseState

#Pull the complete data into the testing object before splitting
testingObject$originalData$GSE8650...Complete <- trainingObject$originalData$PBMC...GSE8650
testingObject$originalData$GSE8650...Complete$formattedName <- "PBMC - GSE8650 - Complete"

#Keep only healthy and SLE for training
keepMe <- rownames(trainingObject$originalData$PBMC...GSE8650$pheno)[trainingObject$originalData$PBMC...GSE8650$pheno$group %in% c("Healthy", "SLE")]
trainingObject$originalData$PBMC...GSE8650 <- subsetOriginalData(trainingObject$originalData$PBMC...GSE8650, keepMe)


######################
# GSE11909
######################
trainingObject$originalData$PBMC...GSE11909$formattedName <- "PBMC - GSE11909"

#Clean up the pheno frame
splitFun <- function(curStr) { return(strsplit(as.character(curStr), ": ")[[1]][[2]]) }
trainingObject$originalData$PBMC...GSE11909$pheno$diseaseState <- sapply(trainingObject$originalData$PBMC...GSE11909$pheno$characteristics_ch1.4, splitFun)

#Set up the class labels
trainingObject$originalData$PBMC...GSE11909$class <- classFunction(trainingObject$originalData$PBMC...GSE11909$pheno, sleTerms = c("SLE"), healthyTerm = "Healthy")
trainingObject$originalData$PBMC...GSE11909$pheno$group <-  trainingObject$originalData$PBMC...GSE11909$pheno$diseaseState

#Pull the complete data into the testing object before splitting
testingObject$originalData$GSE11909...Complete <- trainingObject$originalData$PBMC...GSE11909
testingObject$originalData$GSE11909...Complete$formattedName <- "PBMC - GSE11909 - Complete"

#GSM identifiers for patient first visits, so use those
keepMe <- as.character(read.table("prepData/gse11909samples.tsv")$V1)
trainingObject$originalData$PBMC...GSE11909 <- subsetOriginalData(trainingObject$originalData$PBMC...GSE11909, keepMe)

#########################
# GSE17755
#########################
trainingObject$originalData$PBMC...GSE17755$formattedName <- "PBMC - GSE17755"

#Clean up the pheno frame
splitFun <- function(curStr) { return(strsplit(as.character(curStr), ": ")[[1]][[2]]) }
trainingObject$originalData$PBMC...GSE17755$pheno$age.years <- as.integer(sapply(trainingObject$originalData$PBMC...GSE17755$pheno$characteristics_ch1.1, splitFun))
trainingObject$originalData$PBMC...GSE17755$pheno$diseaseState <- sapply(trainingObject$originalData$PBMC...GSE17755$pheno$characteristics_ch1.2, splitFun)
trainingObject$originalData$PBMC...GSE17755$pheno$sex <- sapply(trainingObject$originalData$PBMC...GSE17755$pheno$characteristics_ch1, splitFun)

trainingObject$originalData$PBMC...GSE17755$pheno$diseaseState[trainingObject$originalData$PBMC...GSE17755$pheno$diseaseState == "systemic lupus erythematosus"] <- "SLE"
trainingObject$originalData$PBMC...GSE17755$pheno$diseaseState[trainingObject$originalData$PBMC...GSE17755$pheno$diseaseState == "healthy individual"] <- "H"

#Set up the class labels
trainingObject$originalData$PBMC...GSE17755$class <- classFunction(trainingObject$originalData$PBMC...GSE17755$pheno, sleTerms = c("SLE"), healthyTerm = "H")
trainingObject$originalData$PBMC...GSE17755$pheno$group <-  trainingObject$originalData$PBMC...GSE17755$pheno$diseaseState

#Pull the complete data into the testing object before splitting
testingObject$originalData$GSE17755...Complete <- trainingObject$originalData$PBMC...GSE17755
testingObject$originalData$GSE17755...Complete$formattedName <- "PBMC - GSE17755 - Complete"

#For training, we only want healthies and controls
keepMe <- rownames(trainingObject$originalData$PBMC...GSE17755$pheno)[trainingObject$originalData$PBMC...GSE17755$pheno$group %in% c("H", "SLE")]
trainingObject$originalData$PBMC...GSE17755<- subsetOriginalData(trainingObject$originalData$PBMC...GSE17755, keepMe)

#Since all SLE samples are adults, lets only keep the adults
keepMe <- rownames(trainingObject$originalData$PBMC...GSE17755$pheno)[trainingObject$originalData$PBMC...GSE17755$pheno$sex %in% c("female") & trainingObject$originalData$PBMC...GSE17755$pheno$age.years >= 18]
trainingObject$originalData$PBMC...GSE17755<- subsetOriginalData(trainingObject$originalData$PBMC...GSE17755, keepMe)

# trainingObject$originalData$PBMC...GSE17755$expr <- trainingObject$originalData$PBMC...GSE17755$expr - 15

#####################
# GSE22098
#####################
trainingObject$originalData$WB...GSE22098$formattedName <- "WB - GSE22098"

#Clean up the pheno frame
splitFun <- function(curStr) { return(strsplit(as.character(curStr), "-")[[1]][[2]]) }
trainingObject$originalData$WB...GSE22098$pheno$diseaseState <- sapply(trainingObject$originalData$WB...GSE22098$pheno$title, splitFun)

splitFun <- function(curStr) { return(strsplit(as.character(curStr), ": ")[[1]][[2]]) }
trainingObject$originalData$WB...GSE22098$pheno$age.years <- as.integer(sapply(trainingObject$originalData$WB...GSE22098$pheno$characteristics_ch1, splitFun))

#Set up the class labels
trainingObject$originalData$WB...GSE22098$class <- classFunction(trainingObject$originalData$WB...GSE22098$pheno, sleTerms = c("ASLE", "PSLE"), healthyTerm = "H")
trainingObject$originalData$WB...GSE22098$pheno$group <-  trainingObject$originalData$WB...GSE22098$pheno$diseaseState

#Pull the complete data into the testing object before splitting
testingObject$originalData$GSE22098...Complete <- trainingObject$originalData$WB...GSE22098
testingObject$originalData$GSE22098...Complete$formattedName <- "WB - GSE22098 - Complete"

#Only keep the the healthy individuals and SLE in our training data
keepMe <- rownames(trainingObject$originalData$WB...GSE22098$pheno)[trainingObject$originalData$WB...GSE22098$pheno$group %in% c("H", "ASLE", "PSLE")]
trainingObject$originalData$WB...GSE22098 <- subsetOriginalData(trainingObject$originalData$WB...GSE22098, keepMe)

#We have both pediatric and adult SLE cases and controls, so split this data into adults and pediatrics
trainingObject$originalData$WB...GSE22098..Adults <- trainingObject$originalData$WB...GSE22098
keepMe <- rownames(trainingObject$originalData$WB...GSE22098..Adults$pheno[trainingObject$originalData$WB...GSE22098..Adults$pheno$age.years >= 18, ])
trainingObject$originalData$WB...GSE22098..Adults <- subsetOriginalData(trainingObject$originalData$WB...GSE22098..Adults, keepMe)
trainingObject$originalData$WB...GSE22098..Adults$formattedName <- "WB - GSE22098 - Adult"

trainingObject$originalData$WB...GSE22098..Pediatric <- trainingObject$originalData$WB...GSE22098
keepMe <- rownames(trainingObject$originalData$WB...GSE22098..Pediatric$pheno[trainingObject$originalData$WB...GSE22098..Pediatric$pheno$age.years < 18, ])
trainingObject$originalData$WB...GSE22098..Pediatric <- subsetOriginalData(trainingObject$originalData$WB...GSE22098..Pediatric, keepMe)
trainingObject$originalData$WB...GSE22098..Pediatric$formattedName <- "WB - GSE22098 - Pediatric"

trainingObject$originalData$WB...GSE22098 <- NULL

# trainingObjectPub <- trainingObject

######################################
# Clean annotations for testing data
######################################
########
#"GSE10325
########
#Easiest to edit manually, then read back in
testingObject$originalData$GSE10325$pheno <- read.csv(file="prepData/gse10325pheno.csv", row.names = 1)

#Set up class labels
testingObject$originalData$GSE10325$class <- classFunction(testingObject$originalData$GSE10325$pheno, sleTerms = c("SLE"), healthyTerm = "Healthy")

#Split object based on cell type
testingObject$originalData$GSE10325...CD4...T <- subsetOriginalData(testingObject$originalData$GSE10325, testingObject$originalData$GSE10325$pheno$cellType == "CD4 T")
testingObject$originalData$GSE10325...CD19...B <- subsetOriginalData(testingObject$originalData$GSE10325, testingObject$originalData$GSE10325$pheno$cellType == "CD19 B")
testingObject$originalData$GSE10325...Myeloid <- subsetOriginalData(testingObject$originalData$GSE10325, testingObject$originalData$GSE10325$pheno$cellType == "Myeloid")

testingObject$originalData$GSE10325...CD4...T$formattedName <- "CD4 T Cells - GSE10325"
testingObject$originalData$GSE10325...CD19...B$formattedName <-  "B Cells - GSE10325"
testingObject$originalData$GSE10325...Myeloid$formattedName <-  "Myeloid Cells - GSE10325"

testingObject$originalData$GSE10325 <- NULL

########
#"GSE26975
#TODO there are both neutrophils and low density granulocytes here, may be worth separating out the LDGs
########
testingObject$originalData$GSE26975$class <- classFunction(testingObject$originalData$GSE26975$pheno, column = "characteristics_ch1.2", sleTerms = c("disease state: lupus"), healthyTerm = "disease state: healthy")
testingObject$originalData$GSE26975$formattedName <- "Neutrophils - GSE26975"

########
#"GSE27427
# TODO characteristics_ch1.5 describes culturing with serum and IFNa in healthy controls: need to remove this
########
testingObject$originalData$GSE27427$class <- classFunction(testingObject$originalData$GSE27427$pheno, column = "characteristics_ch1.1", sleTerms = c("disease state: SLE"), healthyTerm = "disease state: healthy")
testingObject$originalData$GSE27427$formattedName <- "Neutrophils - GSE27427"

#Get the SLEDAI data from external csv
gse27427sledai <- read.csv(file="prepData/gse27427sledai.csv", sep="\t")
gse27427sledai$SLEDAI[gse27427sledai$SLEDAI == "nd"] <- NA
splitFun <- function(curStr) { return(strsplit(as.character(curStr), "_")[[1]][[1]]) }
testingObject$originalData$GSE27427$pheno$patientId <- sapply(as.character(testingObject$originalData$GSE27427$pheno$title), splitFun)
testingObject$originalData$GSE27427$pheno$sledai <- rep(NA, nrow(testingObject$originalData$GSE27427$pheno))
testingObject$originalData$GSE27427$pheno$sledai[gse27427sledai$Patient] <- as.integer(as.character(gse27427sledai$SLEDAI))

########
#GSE30153
########
testingObject$originalData$GSE30153$class <- classFunction(testingObject$originalData$GSE30153$pheno, column = "characteristics_ch1.1", sleTerms = c("disease state: Systemic lupus erythematosous (SLE)"), healthyTerm = "disease state: healthy")
testingObject$originalData$GSE30153$formattedName <- "B Cells - GSE30153"

########
#"GSE32591
########
testingObject$originalData$GSE32591$class <- classFunction(testingObject$originalData$GSE32591$pheno, column = "characteristics_ch1.1", sleTerms = c("disease status: LN patient"), healthyTerm = "disease state: healthy")

#Split apart the tubulo and glomeruli
testingObject$originalData$GSE32591...Tubulo <- subsetOriginalData(testingObject$originalData$GSE32591, testingObject$originalData$GSE32591$pheno$characteristics_ch1.2 == "tissue: Tubulointerstitium from kidney biopsy")
testingObject$originalData$GSE32591...Glomeruli <- subsetOriginalData(testingObject$originalData$GSE32591, testingObject$originalData$GSE32591$pheno$characteristics_ch1.2 == "tissue: Glomeruli from kidney biopsy")

testingObject$originalData$GSE32591...Tubulo$formattedName <- "Kidney - Tubulointerstitium - GSE32591"
testingObject$originalData$GSE32591...Glomeruli$formattedName <- "Kidney - Glomeruli - GSE32591"

testingObject$originalData$GSE32591 <- NULL

########
#"GSE37573"
########
testingObject$originalData$GSE37573$class <- classFunction(testingObject$originalData$GSE37573$pheno, column = "characteristics_ch1.1", sleTerms = c("diagnosis: Systemic Lupus Erythematosus (SLE)"), healthyTerm = "diagnosis: normal")
testingObject$originalData$GSE37573$formattedName <- "B Cells - EBV transformed - GSE37573"

#Note that we have time series data, some with BCRFCR and some with control
#We did this by hand
testingObject$originalData$GSE37573$pheno <- read.csv(file="prepData/gse37573pheno.csv", row.names = 1)

#Split the time and the treatment
splitFun <- function(curStr) { return(strsplit(as.character(curStr), "_")[[1]][[2]]) }
testingObject$originalData$GSE37573$pheno$stim <- sapply(testingObject$originalData$GSE37573$pheno$stimTime, splitFun)

splitFun <- function(curStr) { return(gsub("hr","",strsplit(as.character(curStr), "_")[[1]][[1]])) }
testingObject$originalData$GSE37573$pheno$time <- as.numeric(sapply(testingObject$originalData$GSE37573$pheno$stimTime, splitFun))

########
#"GSE37356
########
testingObject$originalData$GSE37356$class <- classFunction(testingObject$originalData$GSE37356$pheno, column = "characteristics_ch1.2", sleTerms = c("lupus status: case"), healthyTerm = "lupus status: control")

#Split apart the monocytes and macrophages
testingObject$originalData$GSE37356...Mono <- subsetOriginalData(testingObject$originalData$GSE37356, testingObject$originalData$GSE37356$pheno$characteristics_ch1.1 == "cell type: monocyte")
testingObject$originalData$GSE37356...Macro <- subsetOriginalData(testingObject$originalData$GSE37356, testingObject$originalData$GSE37356$pheno$characteristics_ch1.1 == "cell type: macrophage")

testingObject$originalData$GSE37356...Mono$formattedName <- "Monocytes - GSE37356"
testingObject$originalData$GSE37356...Macro$formattedName <- "Macrophages - GSE37356"

testingObject$originalData$GSE37356 <- NULL

########
#"GSE38351"
########
testingObject$originalData$GSE38351$class <- classFunction(testingObject$originalData$GSE38351$pheno, column = "characteristics_ch1.2", sleTerms = c("disease state: SLE"), healthyTerm = "disease state: healthy")
testingObject$originalData$GSE38351$formattedName <- "PBMCs - GSE38351"

########
#GSE4588
########
testingObject$originalData$GSE4588$class <- classFunction(testingObject$originalData$GSE4588$pheno, column = "source_name_ch1", sleTerms = c("SLE patient"), healthyTerm = "Healthy individual")

#Split apart the B and T cells
testingObject$originalData$GSE4588...CD4T <- subsetOriginalData(testingObject$originalData$GSE4588, grep("CD4 T cells", testingObject$originalData$GSE4588$pheno$characteristics_ch1) )
testingObject$originalData$GSE4588...B <- subsetOriginalData(testingObject$originalData$GSE4588, grep("B cells", testingObject$originalData$GSE4588$pheno$characteristics_ch1) )

testingObject$originalData$GSE4588...CD4T$formattedName <- "CD4 T Cells - GSE4588"
testingObject$originalData$GSE4588...B$formattedName <- "B Cells - GSE4588"
testingObject$originalData$GSE4588 <- NULL

########
#"GSE49454
# TODO: previously split out corticosteroids
########
testingObject$originalData$GSE49454$class <- classFunction(testingObject$originalData$GSE49454$pheno, column = "characteristics_ch1", sleTerms = c("group: SLE"), healthyTerm = "group: Healthy control of SLE")
testingObject$originalData$GSE49454$formattedName <- "Whole Blood - GSE49454"

#Pull out the sledai
splitFun <- function(curStr) { a<- strsplit(as.character(curStr), ": ")[[1]]
  if(length(a) ==2) return(a[[2]]) else (return(NA))} 
testingObject$originalData$GSE49454$pheno$sledai <- as.integer(sapply(testingObject$originalData$GSE49454$pheno$characteristics_ch1.6, splitFun))

########
#"GSE50772
########
testingObject$originalData$GSE50772$class <- classFunction(testingObject$originalData$GSE50772$pheno, column = "characteristics_ch1", sleTerms = c("disease status: SLE"), healthyTerm = "disease status: Control")
testingObject$originalData$GSE50772$formattedName <- "PBMCs - GSE50772"

########
#"GSE51997
########
testingObject$originalData$GSE51997$class <- classFunction(testingObject$originalData$GSE51997$pheno, column = "characteristics_ch1", sleTerms = c("blood donor: SLE patient"), healthyTerm = "blood donor: Healthy individual (ND)")

#Split apart the B and T cells
testingObject$originalData$GSE51997...CD4T <- subsetOriginalData(testingObject$originalData$GSE51997, testingObject$originalData$GSE51997$pheno$characteristics_ch1.2 == "cell type: CD4")
testingObject$originalData$GSE51997...CD16pos <- subsetOriginalData(testingObject$originalData$GSE51997, testingObject$originalData$GSE51997$pheno$characteristics_ch1.2 == "cell type: CD16 positive")
testingObject$originalData$GSE51997...CD16neg <- subsetOriginalData(testingObject$originalData$GSE51997, testingObject$originalData$GSE51997$pheno$characteristics_ch1.2 == "cell type: CD16 negative")

testingObject$originalData$GSE51997...CD4T$formattedName <- "CD4 T Cells - GSE51997"
testingObject$originalData$GSE51997...CD16pos$formattedName <- "Monocytes - CD16+ - GSE51997"
testingObject$originalData$GSE51997...CD16neg$formattedName <- "Monocytes - CD16- - GSE51997"
testingObject$originalData$GSE51997 <- NULL

########
#"GSE52471"
########
testingObject$originalData$GSE52471$class <- classFunction(testingObject$originalData$GSE52471$pheno, column = "characteristics_ch1", sleTerms = c("condition: Discoid Lupus"), healthyTerm = "condition: Normal")
testingObject$originalData$GSE52471$formattedName <- "Skin - GSE52471"

########
#"GSE65391
########
testingObject$originalData$GSE65391$class <- classFunction(testingObject$originalData$GSE65391$pheno, column = "characteristics_ch1.10", sleTerms = c("disease state: SLE"), healthyTerm = "disease state: Healthy")
testingObject$originalData$GSE65391$formattedName <- "Whole Blood - GSE65391"

splitFun <- function(curStr) { return(strsplit(as.character(curStr), ": ")[[1]][[2]]) }
testingObject$originalData$GSE65391$pheno$sledai <- as.integer(sapply(testingObject$originalData$GSE65391$pheno$characteristics_ch1.53, splitFun))

########
#"GSE61635
########
testingObject$originalData$GSE61635$class <- classFunction(testingObject$originalData$GSE61635$pheno, column = "characteristics_ch1", sleTerms = c("diagnosis: systemic lupus erythematosus (SLE)"), healthyTerm = "diagnosis: healthy")
testingObject$originalData$GSE61635$formattedName <- "PBMCs - GSE61635"

########
#GSE78193_GPL6480
# This is clinical trial data with no healthies
########
testingObject$originalData$GSE78193_GPL6480$class <- rep(1, length(testingObject$originalData$GSE78193_GPL6480$class))
names(testingObject$originalData$GSE78193_GPL6480$class) <- rownames(testingObject$originalData$GSE78193_GPL6480$pheno)
testingObject$originalData$GSE78193_GPL6480$formattedName <- "Whole Blood - anti-IFNg trial- GSE78193"

########
#GSE78193_GPL6848
# This is IFN stimulated blood
########
testingObject$originalData$GSE78193_GPL6848$class <- rep(0, length(testingObject$originalData$GSE78193_GPL6848$class))
names(testingObject$originalData$GSE78193_GPL6848$class) <- rownames(testingObject$originalData$GSE78193_GPL6848$pheno)
testingObject$originalData$GSE78193_GPL6848$formattedName <- "Whole Blood - IFN stimulated blood- GSE78193"

########
#GSE72747
# Longitudnal patients w/ SLEDAI. 
#TODO generate custom plot
########
testingObject$originalData$GSE72747$class <-rep(1, length(testingObject$originalData$GSE72747$class))
names(testingObject$originalData$GSE72747$class) <- rownames(testingObject$originalData$GSE72747$pheno)
testingObject$originalData$GSE72747$formattedName <- "Whole Blood- GSE72747"

########
#GSE72798
#TODO generate custom plot w/ SLEDAI per patient over time
########
testingObject$originalData$GSE72798$class <- classFunction(testingObject$originalData$GSE72798$pheno, column = "characteristics_ch1.1", sleTerms = c("disease state: SLE", "disease state: lupus nephritis"), healthyTerm = "disease state: healthy")
testingObject$originalData$GSE72798$formattedName <- "Whole Blood - GSE72798"

########
#GSE55447
########
testingObject$originalData$GSE55447$class <- classFunction(testingObject$originalData$GSE55447$pheno, column = "characteristics_ch1.2", sleTerms = c("subject condition: Systemic lupus erythematosus (SLE) patient"), healthyTerm = "subject condition: healthy control")

#Split apart the sorted cells
testingObject$originalData$GSE55447...CD4T <- subsetOriginalData(testingObject$originalData$GSE55447, testingObject$originalData$GSE55447$pheno$characteristics_ch1.5 == "cell type: CD4 positive T cells")
testingObject$originalData$GSE55447...CD8T <- subsetOriginalData(testingObject$originalData$GSE55447, testingObject$originalData$GSE55447$pheno$characteristics_ch1.5 == "cell type: CD8 positive T cells")
testingObject$originalData$GSE55447...CD16M <- subsetOriginalData(testingObject$originalData$GSE55447, testingObject$originalData$GSE55447$pheno$characteristics_ch1.5 == "cell type: CD14 positive monocytes")
testingObject$originalData$GSE55447...CD20B <- subsetOriginalData(testingObject$originalData$GSE55447, testingObject$originalData$GSE55447$pheno$characteristics_ch1.5 == "cell type: CD20 positive B cells")

testingObject$originalData$GSE55447...CD4T$formattedName <- "CD4 T Cells - GSE55447"
testingObject$originalData$GSE55447...CD8T$formattedName <- "CD8 T Cells - GSE55447"
testingObject$originalData$GSE55447...CD16M$formattedName <- "Monocytes - GSE55447"
testingObject$originalData$GSE55447...CD20B$formattedName <- "B Cells - GSE55447"

testingObject$originalData$GSE55447 <- NULL

########
#GSE13887
########
testingObject$originalData$GSE13887$class <- c(rep(0, length(testingObject$originalData$GSE13887$class) -10), rep(1,10))
names(testingObject$originalData$GSE13887$class)  <- rownames(testingObject$originalData$GSE13887$pheno)
testingObject$originalData$GSE13887$formattedName <- "T Cells - GSE13887"

########
#GSE12374
########
testingObject$originalData$GSE12374$class <- c(rep(1,11), rep(0, 6))
names(testingObject$originalData$GSE12374$class) <- rownames(testingObject$originalData$GSE12374$pheno)
testingObject$originalData$GSE12374$formattedName <- "PBMCs - GSE12374"

########
#GSE24706
########
testingObject$originalData$GSE24706$class <- classFunction(testingObject$originalData$GSE24706$pheno, column = "characteristics_ch1.2", sleTerms = c("patient status: SLE patients (SLE)"), healthyTerm = "disease state: healthy")
testingObject$originalData$GSE24706$formattedName <- "PBMCs - GSE24706"

########
#GSE81622
########
testingObject$originalData$GSE81622$class <- c(rep(0,25), rep(1,30))
names(testingObject$originalData$GSE81622$class) <- rownames(testingObject$originalData$GSE81622$pheno)
testingObject$originalData$GSE81622$formattedName <- "PBMCs - GSE81622"

########
#GSE29536
# TODO: there are other diseases here, for ROC would be good to separate
########
testingObject$originalData$GSE29536$class <- classFunction(testingObject$originalData$GSE29536$pheno, column = "characteristics_ch1", sleTerms = c("disease_status: SLE"), healthyTerm = "disease state: healthy")
testingObject$originalData$GSE29536$formattedName <- "Whole Blood - GSE29536"

########
#GSE24060
########
splitFun <- function(curStr) { return(strsplit(as.character(curStr), ": ")[[1]][[2]]) }
testingObject$originalData$GSE24060$pheno$diseaseState <- sapply(testingObject$originalData$GSE24060$pheno$characteristics_ch2.2, splitFun)
testingObject$originalData$GSE24060$pheno$diseaseState[grep("Control",testingObject$originalData$GSE24060$pheno$characteristics_ch2.3)] <- "Control"
testingObject$originalData$GSE24060$pheno$diseaseState[grep("Healthy",testingObject$originalData$GSE24060$pheno$characteristics_ch2.3)] <- "Healthy Twin"

testingObject$originalData$GSE24060$class <- classFunction(testingObject$originalData$GSE24060$pheno, column = "diseaseState", sleTerms = c("SLE"), healthyTerm = "disease state: healthy")
testingObject$originalData$GSE24060$formattedName <- "Whole Blood - GSE24060"

########
#GSE36700
########
testingObject$originalData$GSE36700$class <- classFunction(testingObject$originalData$GSE36700$pheno, column = "characteristics_ch1.1", sleTerms = c("disease: Systemic lupus erythematosus"), healthyTerm = "disease state: healthy")
testingObject$originalData$GSE36700$formattedName <- "Synovial Biopsy - GSE36700"

########
#GSE37426
########
testingObject$originalData$GSE37426$class <- classFunction(testingObject$originalData$GSE37426$pheno, column = "source_name_ch1", sleTerms = c("renal biopsy samples from SLE patient"), healthyTerm = "disease state: healthy")
testingObject$originalData$GSE37426$formattedName <- "Kidney - GSE37426"

########
#GSE36941_GPL10558
# Vitamin D trial, pre- and post-treatment, no healthies
########
testingObject$originalData$GSE36941_GPL10558$class <- rep(1, length(testingObject$originalData$GSE36941_GPL10558$class))
names(testingObject$originalData$GSE36941_GPL10558$class) <- rownames(testingObject$originalData$GSE36941_GPL10558$pheno)
testingObject$originalData$GSE36941_GPL10558$formattedName <- "PBMCs - GSE36941 - GPL10558"

########
#GSE36941_GPL6947
# Vitamin D trial, pre- and post-treatment, no healthies
########
testingObject$originalData$GSE36941_GPL6947$class <- rep(1, length(testingObject$originalData$GSE36941_GPL6947$class))
names(testingObject$originalData$GSE36941_GPL6947$class) <- rownames(testingObject$originalData$GSE36941_GPL6947$pheno)
testingObject$originalData$GSE36941_GPL6947$formattedName <- "PBMCs - GSE36941 - GPL6947"

########
#GSE21649
########
testingObject$originalData$GSE21649$class <- c(rep(0,4), rep(1,4))
names(testingObject$originalData$GSE21649$class) <- rownames(testingObject$originalData$GSE21649$pheno)
testingObject$originalData$GSE21649$formattedName <- "Bone Marrow Derived Stem Cells - GSE21649"

########
#GSE26950
########
testingObject$originalData$GSE26950$class <- rep(1,12)
names(testingObject$originalData$GSE26950$class) <- rownames(testingObject$originalData$GSE26950$pheno)
testingObject$originalData$GSE26950$formattedName <- "Endothelial Progenitor Cells - GSE26950"

########
#GSE26949
# TODO combine this with GSE26950
########
testingObject$originalData$GSE26949$class <- rep(0,12)
names(testingObject$originalData$GSE26949$class) <- rownames(testingObject$originalData$GSE26949$pheno)
testingObject$originalData$GSE26949$formattedName <- "Endothelial Progenitor Cells - GSE26949"

########
#GSE29938
########
testingObject$originalData$GSE29938$class <- classFunction(testingObject$originalData$GSE29938$pheno, column = "characteristics_ch1", sleTerms = c("tissue type: Discoid (DLE) Lesional dermis", "tissue type: Tumid (TLE) Lesional dermis", "tissue type: Subacute cutaneous (SCLE) Lesional dermis"), healthyTerm = "disease state: healthy")
testingObject$originalData$GSE29938$formattedName <- "Skin - GSE29938"

########
#GSE46923
########
testingObject$originalData$GSE46923$class <- classFunction(testingObject$originalData$GSE46923$pheno, column = "characteristics_ch1", sleTerms = c("disease state: systemic lupus erythematosus", "disease state: pediatric systemic lupus erythematosus"), healthyTerm = "disease state: healthy")
testingObject$originalData$GSE46923$formattedName <- "Monocytes - GSE46923"

########
#GSE46920
########
testingObject$originalData$GSE46920$class <- classFunction(testingObject$originalData$GSE46920$pheno, column = "characteristics_ch1.2", sleTerms = c("treatment: SLE serum"), healthyTerm = "disease state: healthy")
testingObject$originalData$GSE46920$formattedName <- "Monocytes - GSE46920"


################
# Read in the GSE88884/5/6 manually
################
#GSE88884 is the baseline data
#GSE88885 is ILLUMINATE1
#GSE88886 is ILLUMINATE2
library(readr)
exprProcess <- function(filename) {
  expr <- readr::read_tsv(filename)
  expr <- as.data.frame(expr)
  rownames(expr) <- expr$probeset
  expr <- expr[,2:ncol(expr)]
  expr <- as.matrix(expr)
  return(expr)
}
gse88884expr <- exprProcess( "prepData/GSE88884_ILLUMINATE1and2_SLEbaselineVsHealthy_preprocessed.txt")
gse88885expr <- exprProcess("prepData/GSE88885_ILLUMINATE1_pd_preprocessed.txt")
gse88886expr <- exprProcess( "prepData/GSE88886_ILLUMINATE2_pd_preprocessed.txt")

seriesProcess <- function(filename) {
  seriesMatrix <- readr::read_delim(filename, delim="\t")
  seriesMatrix <- t(seriesMatrix)
  colnames(seriesMatrix) <- gsub("!","",seriesMatrix[1,])
  colnames(seriesMatrix) <- make.unique(colnames(seriesMatrix))
  seriesMatrix <- seriesMatrix[2:nrow(seriesMatrix),]
  seriesMatrix <- as.data.frame(seriesMatrix)
  
  celSplit <- function(curStr) {
    return(gsub(".gz","",strsplit(curStr,"_")[[1]][[2]]))
  }
  seriesMatrix$cel <- sapply(as.character(seriesMatrix$Sample_supplementary_file), celSplit)
  return(seriesMatrix)
}
gse88884series <- seriesProcess("prepData/GSE88884_series_matrix.txt.mod")
gse88885series <- seriesProcess("prepData/GSE88885_series_matrix.txt")
gse88886series <- seriesProcess("prepData/GSE88886_series_matrix.txt")

gse88884expr <- gse88884expr[,gse88884series$cel]
colnames(gse88884expr) <- rownames(gse88884series)

gse88885expr <- gse88885expr[,gse88885series$cel]
colnames(gse88885expr) <- rownames(gse88885series)

gse88886expr <- gse88886expr[,gse88886series$cel]
colnames(gse88886expr) <- rownames(gse88886series)

keyMatrix <- readr::read_tsv("prepData/GPL17586-45144.txt")
splitFun <- function(curStr) {
  splitStr <- strsplit(curStr,"//")[[1]]
  if(length(splitStr) > 1) {
    geneName <- trimws(splitStr[[2]])
    if(geneName != "" & geneName != "---") {
      return(geneName)
    }
  }
  return(NA)
}
keyMatrix$geneName <- sapply(keyMatrix$gene_assignment, splitFun)
keyMatrix <- as.data.frame(keyMatrix)
rownames(keyMatrix) <- keyMatrix$ID

probeSplit <- function(curStr) {
  return(strsplit(curStr,":")[[1]][[1]])
}

keyFunction <- function(keyNames) {
  probeNames <- sapply(keyNames, probeSplit)
  keyVec <- keyMatrix[probeNames, "geneName"]
  names(keyVec) <- keyNames
  return(keyVec)
}
gse88884keys <- keyFunction(rownames(gse88884expr))
gse88885keys <- keyFunction(rownames(gse88885expr))
gse88886keys <- keyFunction(rownames(gse88886expr))

rownames(gse88884expr) <- names(gse88884keys)
rownames(gse88885expr) <- names(gse88885keys)
rownames(gse88886expr) <- names(gse88886keys)

gse88884class <- as.integer(gse88884series$Sample_characteristics_ch1.2 != "group: Normal")
names(gse88884class) <- rownames(gse88884series)

gse88885class <- as.integer(gse88885series$Sample_characteristics_ch1.2 != "group: Normal")
names(gse88885class) <- rownames(gse88885series)

gse88886class <- as.integer(gse88886series$Sample_characteristics_ch1.2 != "group: Normal")
names(gse88886class) <- rownames(gse88886series)

gse88884originalData <- list(pheno = gse88884series, expr=gse88884expr, class=gse88884class, keys=gse88884keys, formattedName="Whole Blood- GSE88884")
gse88885originalData <- list(pheno = gse88885series, expr=gse88885expr, class=gse88885class, keys=gse88885keys, formattedName="Whole Blood- GSE88885")
gse88886originalData <- list(pheno = gse88886series, expr=gse88886expr, class=gse88886class, keys=gse88886keys, formattedName="Whole Blood- GSE88886")

testingObjectPub$originalData$GSE88884 <- gse88884originalData
testingObjectPub$originalData$GSE88885 <- gse88885originalData
testingObjectPub$originalData$GSE88886 <- gse88886originalData

testingObjectPub <- testingObject
#The following datasets failed checkDataObject() because all keys are NA, so remove them
testingObjectPub$originalData$GSE37426 <- NULL
testingObjectPub$originalData$GSE21649 <- NULL
testingObjectPub$originalData$GSE29938 <- NULL

#########################################################################
# Run the analysis
#########################################################################
#Commented out so that analysis is not inadvertently re-run
# trainingObjectPub$leaveOneOutAnalysis <- NULL
# trainingObjectPub$metaAnalysis <- NULL
# trainingObjectPub <- runMetaAnalysis(trainingObjectPub, maxCores=3)
# save(trainingObjectPub, file="RData/trainingObjectPub.RData")

testingObjectMeta <- testingObjectPub

#All of these only have cases or controls, so can't use for meta-analysis
testingObjectMeta$originalData$GSE78193_GPL6480 <- NULL
testingObjectMeta$originalData$GSE78193_GPL6848 <- NULL
testingObjectMeta$originalData$GSE72747 <- NULL
testingObjectMeta$originalData$GSE36941_GPL10558 <- NULL
testingObjectMeta$originalData$GSE36941_GPL6947 <- NULL
testingObjectMeta$originalData$GSE26950 <- NULL
testingObjectMeta$originalData$GSE26949 <- NULL
testingObjectMeta$originalData$GSE55447...CD4T <- NULL

#GSE37426 is microRNA, so removing
testingObjectMeta$originalData$GSE37426 <- NULL 

#GSE21649 probe mappings are bad, so removing.
#TODO: fix this
testingObjectMeta$originalData$GSE21649 <- NULL 

#GSE29938 is custom affy chip, so removing
# TODO: fix this
testingObjectMeta$originalData$GSE29938 <- NULL 

#No controls in these two
testingObjectMeta$originalData$GSE88885 <- NULL 
testingObjectMeta$originalData$GSE88886 <- NULL 

testingObjectMeta <- runMetaAnalysis(testingObjectMeta, runLeaveOneOutAnalysis = FALSE)
save(testingObjectMeta, file="RData/testingObjectMeta.RData")
load("RData/testingObjectMeta.RData")

#####################
# Set up another object which is only the blood/pbmc samples with healthy and control from testing
#####################
#First get everything that is blood
for(i in 1:length(testingObjectMeta$originalData)) {
  print(testingObjectMeta$originalData[[i]]$formattedName)
}
testingObjectBlood <- list(originalData= list())
testingObjectBlood$originalData$GSE49454 <- testingObjectMeta$originalData$GSE49454
testingObjectBlood$originalData$GSE65391 <- testingObjectMeta$originalData$GSE65391
testingObjectBlood$originalData$GSE61635 <- testingObjectMeta$originalData$GSE61635
testingObjectBlood$originalData$GSE72798 <- testingObjectMeta$originalData$GSE72798
testingObjectBlood$originalData$GSE12374 <- testingObjectMeta$originalData$GSE12374
testingObjectBlood$originalData$GSE24706 <- testingObjectMeta$originalData$GSE24706
testingObjectBlood$originalData$GSE81622 <- testingObjectMeta$originalData$GSE81622
testingObjectBlood$originalData$GSE24060 <- testingObjectMeta$originalData$GSE24060

#Now see which have healthies and SLE
#Remove treated patients
testingObjectBlood$originalData$GSE72798 <- subsetOriginalData(testingObjectBlood$originalData$GSE72798, keepMe = 
                                                                 (testingObjectBlood$originalData$GSE72798$pheno$characteristics_ch1.9 == "time: prior to administration of immunosuppressive therapy") |  
                                                                 (testingObjectBlood$originalData$GSE72798$pheno$characteristics_ch1.11 =="time: baseline (month 0)") | 
                                                                 (testingObjectBlood$originalData$GSE72798$pheno$characteristics_ch1.10 =="agent: untreated"))

testingObjectBlood$originalData$GSE24060 <- subsetOriginalData(testingObjectBlood$originalData$GSE24060, keepMe = (testingObjectBlood$originalData$GSE24060$pheno$characteristics_ch2.2 =="disease subtype: SLE"))

#Keep only first-visits
testingObjectBlood$originalData$GSE49454 <- subsetOriginalData(testingObjectBlood$originalData$GSE49454, keepMe =(testingObjectBlood$originalData$GSE49454$pheno$characteristics_ch1 == "group: Healthy control of SLE") |
                      rownames(testingObjectBlood$originalData$GSE49454$pheno) %in% c("GSM1199435", "GSM1199504", "GSM1199537", "GSM1199513", 
                     "GSM1199540", "GSM1199480", "GSM1199498", "GSM1199403", "GSM1199461", 
                     "GSM1199482", "GSM1199543", "GSM1199521", "GSM1199462", "GSM1199407", 
                     "GSM1199494", "GSM1199520", "GSM1199388", "GSM1199458", "GSM1199479", 
                     "GSM1199427", "GSM1199433", "GSM1199353", "GSM1199502", "GSM1199434", 
                     "GSM1199404", "GSM1199487", "GSM1199421", "GSM1199459", "GSM1199447", 
                     "GSM1199446", "GSM1199496", "GSM1199538", "GSM1199409", "GSM1199506", 
                     "GSM1199448", "GSM1199547", "GSM1199425", "GSM1199359", "GSM1199491", 
                     "GSM1199441", "GSM1199507", "GSM1199411", "GSM1199355", "GSM1199533", 
                     "GSM1199429", "GSM1199401", "GSM1199495", "GSM1199532", "GSM1199364", 
                     "GSM1199514", "GSM1199360", "GSM1199466", "GSM1199542", "GSM1199460", 
                     "GSM1199512", "GSM1199367", "GSM1199428", "GSM1199438", "GSM1199544", 
                     "GSM1199484", "GSM1199414", "GSM1199416"))

testingObjectBlood$originalData$GSE24060 <- NULL

testingObjectBlood$originalData$GSE65391 <- subsetOriginalData(testingObjectBlood$originalData$GSE65391, keepMe = testingObjectBlood$originalData$GSE65391$pheno$characteristics_ch1.6 %in% c("cumulative_time: 0", "cumulative_time: Not Applicable"))


testingObjectBlood$originalData$GSE88884 <- gse88884originalData

rownames(testingObjectBlood$originalData$GSE88884$expr) <- 1:nrow(testingObjectBlood$originalData$GSE88884$expr)
names(testingObjectBlood$originalData$GSE88884$keys) <- 1:nrow(testingObjectBlood$originalData$GSE88884$expr)
testingObjectBlood <- runMetaAnalysis(testingObjectBlood, runLeaveOneOutAnalysis = F)
save(testingObjectBlood, file="RData/testingObjectBlood.RData")
save(testingObjectPub, file="RData/testingObjectPub.RData")

################
# Validate training signature in testing data
################
## Examine signature in the testing data
pooledTesting <- testingObjectBlood$metaAnalysis$pooledResults[c(curFilter$posGeneNames, curFilter$negGeneNames),]
# Number of genes which were also ES >1 and FDR < 0.05 in testing
sum(abs(pooledTesting$effectSize) > 1 & pooledTesting$effectSizeFDR < 0.05)
#Make sure the sign agrees in the up and down genes
sum(sign(pooledTesting[curFilter$posGeneNames, "effectSize"]))/length(curFilter$posGeneNames)
sum(sign(pooledTesting[curFilter$negGeneNames, "effectSize"]))/length(curFilter$negGeneNames)
summary(abs(pooledTesting$effectSize))

pooledTestingNonSig <- pooledTesting[abs(pooledTesting$effectSize) < 1 | pooledTesting$effectSizeFDR > 0.05, ]
summary(pooledTestingNonSig[,c("effectSize", "effectSizeFDR")])

################
# Build Table S1
################
sleGenes <- c(curFilter$posGeneNames, curFilter$negGeneNames)
trainingFrame <- trainingObjectPub$metaAnalysis$pooledResults
testingFrame <- testingObjectBlood$metaAnalysis$pooledResults

trainingFrame <- trainingFrame[sleGenes,]
testingFrame <- testingFrame[sleGenes,]

colnames(trainingFrame) <- paste("Training", colnames(trainingFrame))
colnames(testingFrame) <- paste("Testing", colnames(testingFrame))

tableS1 <- cbind(trainingFrame, testingFrame)
write.csv(tableS1, file="TableS1.csv")

##################
# DEAP analysis
##################

#Run pathway analysis
library(MetaIntegratorPrivate)
deapRes <- pathwayAnalysis(trainingObjectPub, numShuffles=1e3)
save(deapRes, file="RData/deapRes.RData")
testingObjectBlood <- runMetaAnalysis(testingObjectBlood)
testDeap <- pathwayAnalysis(testingObjectBlood, numShuffles=1e3)
save(testDeap, file="RData/testDeap.RData")

mergedMeta <- list(originalData=c(trainingObjectPub$originalData, testingObjectBlood$originalData))
mergedMetaRun <- runMetaAnalysis(mergedMeta, runLeaveOneOutAnalysis = FALSE)
mergedMetaDeap <- pathwayAnalysis(mergedMetaRun, numShuffles=5e3)

mergedMetaDeap <- mergedMetaDeap[mergedMetaDeap$X..AbsValue != 0,]
mergedMetaDeap$pVal <- mergedMetaDeap$pVal + 0.001
mergedMetaDeap$FDR <- p.adjust(mergedMetaDeap$pVal, method = "fdr")

save(mergedMetaDeap, file="RData/mergedMetaDeap.RData")


load("RData/mergedMetaDeap.RData")
table2 <- mergedMetaDeap
table2 <- table2[table2$pVal < 0.05,]
table2 <- table2[,c("PathwayName","pVal","FDR","X..AbsValue", "X..PathwaySubset")]
colnames(table2) <- c("Pathway Name", "p-Value", "False Discovery Rate", "DEAP Statistic","Pathway Subpath")
table2[,2:4] <- signif(table2[,2:4], digits = 3)
write.table(table2, file=paste("plots/table2.tsv",sep=""), sep="\t", row.names = F, quote=F)
