library(MetaIntegratorPrivateLupus)
library(gplots)
library(ggplot2)
library(cowplot)
library(ggpubr)
library(forcats)


##########
# Load the data
##########
load(file="RData/curFilter.RData")
sleFilter <- curFilter
load("RData/trainingObjectPub.RData")
load("RData/testingObjectPub.RData")
load("RData/testingObjectBlood.RData")
load("RData/testingObjectMeta.RData")

modFilter <- function(sleFilter, curIFN) {
  ifnFilter <- sleFilter
  nonIfnFilter <- sleFilter
  
  ifnFilter$posGeneNames <- intersect(sleFilter$posGeneNames, curIFN)
  ifnFilter$negGeneNames <- intersect(sleFilter$negGeneNames, curIFN)
  
  nonIfnFilter$posGeneNames <- setdiff(sleFilter$posGeneNames, curIFN)
  nonIfnFilter$negGeneNames <- setdiff(sleFilter$negGeneNames, curIFN)
  
  ifnFilter$filterDescription <- paste(ifnFilter$filterDescription, "IFN related only.")
  nonIfnFilter$filterDescription <- paste(nonIfnFilter$filterDescription, "non-IFN related only.")
  return(list(ifn=ifnFilter, nonIfn = nonIfnFilter))
}

###########
# Specific plots for publication
###########
labelSplit <- function(curStr) {
  a <- strsplit(as.character(curStr), split = ": ")[[1]]
  if(length(a) >= 2) {
    return(a[[2]])
  } else {
    return(NA)
  }
  
}
geneOrder <- trainingObjectPub$metaAnalysis$pooledResults$effectSize
names(geneOrder) <- rownames(trainingObjectPub$metaAnalysis$pooledResults)
geneOrder <- geneOrder[c(sleFilter$posGeneNames, sleFilter$negGeneNames)]
geneOrder <- geneOrder[order(geneOrder)]

trainingHeatmap <- heatmapPlot(trainingObjectPub, sleFilter, colorRange = c(-2,2), geneOrder=names(geneOrder))
testingHeatmap <- heatmapPlot(testingObjectBlood, sleFilter, colorRange = c(-2,2), geneOrder=names(geneOrder))

testingObjectMeta$originalData$GSE11909...Complete$formattedName <- "PBMCs - GSE11909"
testingObjectMeta$originalData$GSE17755...Complete$formattedName <- "PBMCs - GSE17755"
testingObjectMeta$originalData$GSE8650...Complete$formattedName <- "PBMCs - GSE8650"
testingObjectMeta$originalData$GSE22098...Complete$formattedName <- "Whole Blood - GSE22098"
testingObjectMeta$originalData$GSE39088...Complete$formattedName <- "Whole Blood - GSE39088"
testingObjectMeta$originalData$GSE29536$formattedName <- "Whole Blood - GSE29536"
nameFun<- function(obj) {  obj$formattedName }
nameFrame <- data.frame(originalName = names(testingObjectMeta$originalData), 
                        formattedName = sapply(testingObjectMeta$originalData, nameFun))
nameFrame <- nameFrame[order(nameFrame$formattedName),]
nameFrame <- nameFrame[! (nameFrame$originalName %in% names(testingObjectBlood$originalData)), ]
bloodTissueFormatted <- c(grep("PBMC", nameFrame$formattedName), grep("Whole Blood", nameFrame$formattedName), 
                          grep("Kidney", nameFrame$formattedName),
                          grep("Skin", nameFrame$formattedName), grep("Synovial", nameFrame$formattedName))
nameFrame <- nameFrame[c(bloodTissueFormatted, setdiff(1:nrow(nameFrame), bloodTissueFormatted)),]

extendedTestingHeatmap <- heatmapPlot(testingObjectMeta, sleFilter, colorRange = c(-2,2), geneOrder=names(geneOrder), 
                                      datasetOrder = as.character(nameFrame$originalName))

##################
# ROC plots
##################
#Training
trainingROC <- summaryROCPlot(trainingObjectPub, sleFilter)
#Testing
testingROC <- summaryROCPlot(testingObjectBlood, filterObject= sleFilter)
#ExtendedTesting
extendedTestingROC <- summaryROCPlot(testingObjectMeta, filterObject= sleFilter)

##################
# Disease Activity
##################
#SLEDAI regression plots

hexPlot <- function(regPlotObj) {
  
  layers <- lapply(regPlotObj$layers, function(x) {
    if (class(x$geom)[1] %in% c("GeomPoint", "GeomSmooth")) {
      NULL
    } else {
      x
    }
  })
  layers <- layers[!sapply(layers, is.null)]
  regPlotObj$layers <- layers
  regPlotObj <- regPlotObj + geom_hex(bins=20) + scale_fill_gradient(low="grey90",high="orange")
  regPlotObj$layers <- regPlotObj$layers[c(2,1)]
  return(regPlotObj)
}

gse27427sledai <- regressionPlot(filterObject = sleFilter, datasetObject = testingObjectPub$originalData$GSE27427,
                                 continuousVariableColumn = "sledai", formattedVariableName="SLEDAI")

gse8650sledai <- regressionPlot(filterObject = sleFilter, datasetObject = testingObjectPub$originalData$GSE8650...Complete,
                                continuousVariableColumn = "sledai", formattedVariableName="SLEDAI", corMethod="spearman")

gse49454sledai <- regressionPlot(filterObject= sleFilter, datasetObject = testingObjectPub$originalData$GSE49454, 
                                 continuousVariableColumn =  "sledai", formattedVariableName = "SLEDAI", corMethod="spearman")

gse65391sledai <- regressionPlot(filterObject= sleFilter, datasetObject = testingObjectPub$originalData$GSE65391, 
                                 continuousVariableColumn =  "sledai", formattedVariableName = "SLEDAI", corMethod="spearman")
gse88884sledai<- regressionPlot(filterObject= sleFilter, datasetObject = testingObjectPub$originalData$GSE88884, 
                                continuousVariableColumn =  "sledai", formattedVariableName = "SLEDAI", corMethod="spearman")

testingObjectPub$originalData$GSE65391$pheno$esr <- sapply(testingObjectPub$originalData$GSE65391$pheno$characteristics_ch1.26, labelSplit)
testingObjectPub$originalData$GSE65391$pheno$esr[testingObjectPub$originalData$GSE65391$pheno$esr %in% c("Data Not Available", "Not Applicable")] <- NA
testingObjectPub$originalData$GSE65391$pheno$esr <- as.numeric(testingObjectPub$originalData$GSE65391$pheno$esr)
gse65391esr <- regressionPlot(filterObject= sleFilter, datasetObject = testingObjectPub$originalData$GSE65391, 
                              continuousVariableColumn =  "esr", formattedVariableName = "Erythrocyte Sedementation Rate", corMethod="spearman")

testingObjectPub$originalData$GSE65391$pheno$c3 <- sapply(testingObjectPub$originalData$GSE65391$pheno$characteristics_ch1.37, labelSplit)
testingObjectPub$originalData$GSE65391$pheno$c3[testingObjectPub$originalData$GSE65391$pheno$c3 %in% c("Data Not Available", "Not Applicable")] <- NA
testingObjectPub$originalData$GSE65391$pheno$c3 <- as.numeric(testingObjectPub$originalData$GSE65391$pheno$c3)
gse65391c3 <- regressionPlot(filterObject= sleFilter, datasetObject = testingObjectPub$originalData$GSE65391, 
                             continuousVariableColumn =  "c3", formattedVariableName = "Complement Component 3")

testingObjectPub$originalData$GSE65391$pheno$c4 <- sapply(testingObjectPub$originalData$GSE65391$pheno$characteristics_ch1.38, labelSplit)
testingObjectPub$originalData$GSE65391$pheno$c4[testingObjectPub$originalData$GSE65391$pheno$c4 %in% c("Data Not Available", "Not Applicable")] <- NA
testingObjectPub$originalData$GSE65391$pheno$c4 <- as.numeric(testingObjectPub$originalData$GSE65391$pheno$c4)
gse65391c4 <- regressionPlot(filterObject= sleFilter, datasetObject = testingObjectPub$originalData$GSE65391, 
                             continuousVariableColumn =  "c4", formattedVariableName = "Complement Component 4")


##################
# Multiple diseases
##################

# GSE29536
curObj <- testingObjectPub$originalData$GSE29536
curObj$pheno$diseaseState <- sapply(curObj$pheno$characteristics_ch1, labelSplit)
curObj$pheno$diseaseState <- as.factor(gsub("\\\\n","", as.character(curObj$pheno$diseaseState)))
curObj$pheno$diseaseState <- as.character(curObj$pheno$diseaseState)
curObj$pheno$diseaseState[grepl("AHI", curObj$pheno$diseaseState)] <- "HIV"
curObj$pheno$diseaseState[grepl("Control", curObj$pheno$diseaseState)] <- "Control"
curObj$pheno$diseaseState[grepl("Healthy", curObj$pheno$diseaseState)] <- "Control"
curObj$pheno$diseaseState[grepl("Reference", curObj$pheno$diseaseState)] <- "Control"
curObj$pheno$diseaseState[grepl("Recovery", curObj$pheno$diseaseState)] <- "Recov. Meliodosis"
curObj$pheno$diseaseState[grepl("PTB", curObj$pheno$diseaseState)] <- "TB"
curObj$pheno$diseaseState[grepl("SOJIA", curObj$pheno$diseaseState)] <- "JIA"
curObj$pheno$diseaseState[grepl("B CELL", curObj$pheno$characteristics_ch1.1) & grepl("Patient", curObj$pheno$diseaseState)] <- "B Cell Defic."
curObj$pheno$diseaseState[grepl("ACR", curObj$pheno$diseaseState)] <- "Liver Transplant AR"
curObj$pheno$diseaseState <- as.factor(curObj$pheno$diseaseState)
levelOrder <- levels(curObj$pheno$diseaseState)
levelOrder <- c("SLE", levelOrder[levelOrder != "SLE"])
curObj$pheno$diseaseState <- factor(as.character(curObj$pheno$diseaseState), levels=levelOrder)
gse29536plot <- MetaIntegratorLupus::violinPlot(autoLineBreak=FALSE, sleFilter, curObj, "diseaseState")

# GSE8650
diseaseVec <- as.character(testingObjectPub$originalData$GSE8650...Complete$pheno$diseaseState)
diseaseVec[diseaseVec=="PAPA"] <- "PAPA"
diseaseVec[diseaseVec=="JIA Systemic Onset"] <- "JIA"
levelOrder <- levels(as.factor(diseaseVec))
levelOrder <- c("SLE", levelOrder[levelOrder != "SLE"])
testingObjectPub$originalData$GSE8650...Complete$pheno$diseaseState <- factor(diseaseVec, levels=levelOrder)
gse8650plot <- MetaIntegratorLupus::violinPlot(autoLineBreak=FALSE, sleFilter,testingObjectPub$originalData$GSE8650...Complete, "diseaseState")

# GSE22098
diseaseVec <- as.character(testingObjectPub$originalData$GSE22098...Complete$pheno$diseaseState)
diseaseVec[diseaseVec == "H"] <- "Healthy"
diseaseVec[diseaseVec == "Still"] <- "Still's"
diseaseVec <- fct_recode(diseaseVec,
                         "aSLE" = "ASLE",
                         "pSLE" = "PSLE")
levelOrder <- levels(as.factor(diseaseVec))
levelOrder <- c("pSLE","aSLE", levelOrder[ !levelOrder %in% c("aSLE","pSLE")])
testingObjectPub$originalData$GSE22098...Complete$pheno$diseaseState <- factor(diseaseVec, levels=levelOrder)
testingObjectPub$originalData$GSE22098...Complete$formattedName <- "Whole Blood - GSE22098"
datasetPheno <- testingObjectPub$originalData$GSE22098...Complete$pheno
datasetPheno$x <- datasetPheno$diseaseState
remove_geom <- function(ggplot2_object, geom_type) {
  # Delete layers that match the requested type.
  layers <- lapply(ggplot2_object$layers, function(x) {
    if (class(x$geom)[1] == geom_type) {
      NULL
    } else {
      x
    }
  })
  # Delete the unwanted layers.
  layers <- layers[!sapply(layers, is.null)]
  ggplot2_object$layers <- layers
  ggplot2_object
}
gse22098plot <- MetaIntegratorLupus::violinPlot(autoLineBreak=FALSE, sleFilter,testingObjectPub$originalData$GSE22098...Complete, "diseaseState") 
gse22098plot <- remove_geom(gse22098plot, "GeomSignif")
comparisonList <- split(matrix(c( rep("ASLE",(length(levels(datasetPheno$x))-2)),
                                  rep("PSLE",(length(levels(datasetPheno$x))-1)),
                                  levels(datasetPheno$x)[c(3:(length(levels(datasetPheno$x))))],
                                  "ASLE",levels(datasetPheno$x)[c(3:(length(levels(datasetPheno$x))))])
                               ,ncol=2, byrow = F), 1:9)

gse22098plot <- gse22098plot +  stat_compare_means(comparisons= comparisonList, method="wilcox.test", tip.length = 0.01) + 
  scale_x_discrete(labels=levelOrder)



#GSE38351
diseaseVec <- as.character(testingObjectPub$originalData$GSE38351$pheno$`disease state`)
levelOrder <- levels(as.factor(diseaseVec))
levelOrder <- c("SLE", levelOrder[levelOrder != "SLE"])
testingObjectPub$originalData$GSE38351$pheno$diseaseState <- factor(diseaseVec, levels=levelOrder)
gse38351plot <- MetaIntegratorLupus::violinPlot(autoLineBreak=FALSE, sleFilter,testingObjectPub$originalData$GSE38351, "diseaseState")



#################
# Multiple Tissues
#################

# GSE36700
diseaseVec <- as.character(testingObjectPub$originalData$GSE36700$pheno$disease)
diseaseVec[diseaseVec == "Systemic lupus erythematosus"] <- "SLE"
diseaseVec <- fct_recode(diseaseVec,
                         "OA" = "Osteoarthritis",
                         "RA" = "Rheumatoid arthritis",
                         "Crystal Arth" = "Microcrystalline arthritis",
                         "SA" = "Seronegative arthritis")
diseaseVec <- factor(diseaseVec, levels=c("SLE", "Crystal Arth", "OA", "RA", "SA"))
testingObjectPub$originalData$GSE36700$pheno$diseaseState <- diseaseVec
gse36700plot <- MetaIntegratorLupus::violinPlot(autoLineBreak=FALSE, sleFilter,testingObjectPub$originalData$GSE36700, "diseaseState")

# GSE32591
diseaseVec <- as.character(testingObjectPub$originalData$GSE32591...Glomeruli$pheno$characteristics_ch1.1)
diseaseVec[diseaseVec == "disease status: LN patient"] <- "Lupus Nephritis"
diseaseVec[diseaseVec == "disease status: control"] <- "Control"
levelOrder <- levels(as.factor(diseaseVec))
levelOrder <- c("Lupus Nephritis", levelOrder[levelOrder != "Lupus Nephritis"])
testingObjectPub$originalData$GSE32591...Glomeruli$pheno$diseaseState <- factor(diseaseVec, levels=levelOrder)
gse32591glomPlot <- MetaIntegratorLupus::violinPlot(autoLineBreak=FALSE, sleFilter,testingObjectPub$originalData$GSE32591...Glomeruli, "diseaseState")

diseaseVec <- as.character(testingObjectPub$originalData$GSE32591...Tubulo$pheno$characteristics_ch1.1)
diseaseVec[diseaseVec == "disease status: LN patient"] <- "Lupus Nephritis"
diseaseVec[diseaseVec == "disease status: control"] <- "Control"
levelOrder <- levels(as.factor(diseaseVec))
levelOrder <- c("Lupus Nephritis", levelOrder[levelOrder != "Lupus Nephritis"])
testingObjectPub$originalData$GSE32591...Tubulo$pheno$diseaseState <- factor(diseaseVec, levels=levelOrder)
gse32591tubPlot <- MetaIntegratorLupus::violinPlot(autoLineBreak=FALSE, sleFilter,testingObjectPub$originalData$GSE32591...Tubulo, "diseaseState")

#GSE52471
diseaseVec <- as.character(testingObjectPub$originalData$GSE52471$pheno$condition)
diseaseVec[diseaseVec=="Normal"] <- "Healthy"
testingObjectPub$originalData$GSE52471$pheno$diseaseState <- factor(diseaseVec)
gse52471plot <- MetaIntegratorLupus::violinPlot(autoLineBreak=FALSE, sleFilter,testingObjectPub$originalData$GSE52471, "diseaseState")


############
# Cell Types
############

### CD4T
#GSE10325
diseaseVec <- as.character(testingObjectPub$originalData$GSE10325...CD4...T$pheno$diseaseState)
levelOrder <- levels(as.factor(diseaseVec))
levelOrder <- c("SLE", levelOrder[levelOrder != "SLE"])
testingObjectPub$originalData$GSE10325...CD4...T$pheno$diseaseState <- factor(diseaseVec, levels=levelOrder)
GSE10325CD4Tplot <- MetaIntegratorLupus::violinPlot(autoLineBreak=FALSE, sleFilter,testingObjectPub$originalData$GSE10325...CD4...T, "diseaseState")

#GSE51997
diseaseVec <- as.character(testingObjectPub$originalData$GSE51997...CD4T$pheno$characteristics_ch1)
diseaseVec[diseaseVec=="blood donor: Healthy individual (ND)"] <- "Healthy"
diseaseVec[diseaseVec=="blood donor: SLE patient"] <- "SLE"
levelOrder <- levels(as.factor(diseaseVec))
levelOrder <- c("SLE", levelOrder[levelOrder != "SLE"])
testingObjectPub$originalData$GSE51997...CD4T$pheno$diseaseState <- factor(diseaseVec, levels=levelOrder)
GSE51997CD4Tplot <- MetaIntegratorLupus::violinPlot(autoLineBreak=FALSE, sleFilter,testingObjectPub$originalData$GSE51997...CD4T, "diseaseState")

#GSE4588
diseaseVec <- as.character(testingObjectPub$originalData$GSE4588...CD4T$pheno$characteristics_ch1)
diseaseVec[diseaseVec=="CD4 T cells sorted from total PBMC of patient with systemic lupus erythematosus"] <- "SLE"
diseaseVec[diseaseVec=="CD4 T cells sorted from total PBMC of patient with rheumatoid arthritis" ] <- "RA"
diseaseVec[diseaseVec=="CD4 T cells sorted from total PBMC of healthy subject" ] <- "Healthy"
levelOrder <- levels(as.factor(diseaseVec))
levelOrder <- c("SLE", levelOrder[levelOrder != "SLE"])
testingObjectPub$originalData$GSE4588...CD4T$pheno$diseaseState <- factor(diseaseVec, levels=levelOrder)
GSE4588CD4Tplot <- MetaIntegratorLupus::violinPlot(autoLineBreak=FALSE, sleFilter,testingObjectPub$originalData$GSE4588...CD4T, "diseaseState")

#GSE55447
diseaseVec <- as.character(testingObjectPub$originalData$GSE55447...CD4T$pheno$characteristics_ch1.2)
diseaseVec[diseaseVec=="subject condition: Systemic lupus erythematosus (SLE) patient"] <- "SLE"
diseaseVec[grepl("Control",testingObjectPub$originalData$GSE55447...CD4T$pheno$source_name_ch1) ] <- "Healthy"
levelOrder <- levels(as.factor(diseaseVec))
levelOrder <- c("SLE", levelOrder[levelOrder != "SLE"])
testingObjectPub$originalData$GSE55447...CD4T$pheno$diseaseState <- factor(diseaseVec, levels=levelOrder)
GSE55447CD4Tplot <- MetaIntegratorLupus::violinPlot(autoLineBreak=FALSE, sleFilter,testingObjectPub$originalData$GSE55447...CD4T, "diseaseState")

### CD8T
# GSE55447
diseaseVec <- as.character(testingObjectPub$originalData$GSE55447...CD8T$pheno$characteristics_ch1.2)
diseaseVec[diseaseVec=="subject condition: Systemic lupus erythematosus (SLE) patient"] <- "SLE"
diseaseVec[diseaseVec=="subject condition: healthy control" ] <- "Healthy"
levelOrder <- levels(as.factor(diseaseVec))
levelOrder <- c("SLE", levelOrder[levelOrder != "SLE"])
testingObjectPub$originalData$GSE55447...CD8T$pheno$diseaseState <- factor(diseaseVec, levels=levelOrder)
GSE55447CD8Tplot <- MetaIntegratorLupus::violinPlot(autoLineBreak=FALSE, sleFilter,testingObjectPub$originalData$GSE55447...CD8T, "diseaseState")

### B Cells
# GSE4588
diseaseVec <- as.character(testingObjectPub$originalData$GSE4588...B$pheno$characteristics_ch1)
diseaseVec[diseaseVec=="B cells sorted from total PBMC of systemic lupus erythematosus patient"] <- "SLE"
diseaseVec[diseaseVec=="B cells sorted from total PBMC of RA patient" ] <- "Rheumatoid Arthritis"
diseaseVec[diseaseVec=="B cells sorted from total PBMC of healthy subject" ] <- "Healthy"
levelOrder <- levels(as.factor(diseaseVec))
levelOrder <- c("SLE", levelOrder[levelOrder != "SLE"])
testingObjectPub$originalData$GSE4588...B$pheno$diseaseState <- factor(diseaseVec, levels=levelOrder)
GSE4588Bplot <- MetaIntegratorLupus::violinPlot(autoLineBreak=FALSE, sleFilter,testingObjectPub$originalData$GSE4588...B, "diseaseState")

# GSE10325
diseaseVec <- as.character(testingObjectPub$originalData$GSE10325...CD19...B$pheno$diseaseState)
levelOrder <- levels(as.factor(diseaseVec))
levelOrder <- c("SLE", levelOrder[levelOrder != "SLE"])
testingObjectPub$originalData$GSE10325...CD19...B$pheno$diseaseState <- factor(diseaseVec, levels=levelOrder)
GSE10325Bplot <- MetaIntegratorLupus::violinPlot(autoLineBreak=FALSE, sleFilter,testingObjectPub$originalData$GSE10325...CD19...B, "diseaseState")

# GSE55447
diseaseVec <- as.character(testingObjectPub$originalData$GSE55447...CD20B$pheno$characteristics_ch1.2)
diseaseVec[diseaseVec=="subject condition: Systemic lupus erythematosus (SLE) patient"] <- "SLE"
diseaseVec[diseaseVec=="subject condition: healthy control" ] <- "Healthy"
levelOrder <- levels(as.factor(diseaseVec))
levelOrder <- c("SLE", levelOrder[levelOrder != "SLE"])
testingObjectPub$originalData$GSE55447...CD20B$pheno$diseaseState <- factor(diseaseVec, levels=levelOrder)
GSE55447Bplot <- MetaIntegratorLupus::violinPlot(autoLineBreak=FALSE, sleFilter,testingObjectPub$originalData$GSE55447...CD20B, "diseaseState")


# GSE30153
diseaseVec <- as.character(testingObjectPub$originalData$GSE30153$pheno$characteristics_ch1.1)
diseaseVec[grepl("SLE", diseaseVec)] <- "SLE"
diseaseVec[grepl("control", diseaseVec)] <- "Healthy"
levelOrder <- levels(as.factor(diseaseVec))
levelOrder <- c("SLE", levelOrder[levelOrder != "SLE"])
testingObjectPub$originalData$GSE30153$pheno$diseaseState <- factor(diseaseVec, levels=levelOrder)
GSE30153plot <- MetaIntegratorLupus::violinPlot(autoLineBreak=FALSE, sleFilter,testingObjectPub$originalData$GSE30153, "diseaseState")


################
# Cell proportions
################

# GSE49454
#There were some issues with column alignments in this annotation table, so write to csv, edit, and load back
write.csv(testingObjectPub$originalData$GSE49454$pheno, file="prepData/GSE49454_pre.csv")
testingObjectPub$originalData$GSE49454$pheno <- read.csv( file="prepData/GSE49454_post.csv")
rownames(testingObjectPub$originalData$GSE49454$pheno) <- testingObjectPub$originalData$GSE49454$pheno$X
testingObjectPub$originalData$GSE49454$pheno <- testingObjectPub$originalData$GSE49454$pheno[,2:ncol(testingObjectPub$originalData$GSE49454$pheno)]
testingObjectPub$originalData$GSE49454$expr <- testingObjectPub$originalData$GSE49454$expr[,rownames(testingObjectPub$originalData$GSE49454$pheno)] 
testingObjectPub$originalData$GSE49454$class <- testingObjectPub$originalData$GSE49454$class[colnames(testingObjectPub$originalData$GSE49454$expr)]

testingObjectPub$originalData$GSE49454$pheno$cd4Count <- as.integer(sapply(testingObjectPub$originalData$GSE49454$pheno$characteristics_ch1.29, labelSplit))
testingObjectPub$originalData$GSE49454$pheno$cd8Count <- as.integer(sapply(testingObjectPub$originalData$GSE49454$pheno$characteristics_ch1.30, labelSplit))
testingObjectPub$originalData$GSE49454$pheno$bCount <- as.integer(sapply(testingObjectPub$originalData$GSE49454$pheno$characteristics_ch1.31, labelSplit))
testingObjectPub$originalData$GSE49454$pheno$nkCount <- as.integer(sapply(testingObjectPub$originalData$GSE49454$pheno$characteristics_ch1.32, labelSplit))
testingObjectPub$originalData$GSE49454$pheno$eoCount <- as.integer(sapply(testingObjectPub$originalData$GSE49454$pheno$characteristics_ch1.33, labelSplit))
testingObjectPub$originalData$GSE49454$pheno$neutroCount <- as.integer(sapply(testingObjectPub$originalData$GSE49454$pheno$characteristics_ch1.27, labelSplit))
testingObjectPub$originalData$GSE49454$pheno$lymphCount <- as.integer(sapply(testingObjectPub$originalData$GSE49454$pheno$characteristics_ch1.28, labelSplit))
testingObjectPub$originalData$GSE49454$pheno$leukCount <- as.integer(sapply(testingObjectPub$originalData$GSE49454$pheno$characteristics_ch1.26, labelSplit))

totalCount <- testingObjectPub$originalData$GSE49454$pheno$cd4Count + testingObjectPub$originalData$GSE49454$pheno$cd8Count + testingObjectPub$originalData$GSE49454$pheno$bCount +
  testingObjectPub$originalData$GSE49454$pheno$nkCount  +testingObjectPub$originalData$GSE49454$pheno$eoCount + testingObjectPub$originalData$GSE49454$pheno$neutroCount +
  testingObjectPub$originalData$GSE49454$pheno$lymphCount + testingObjectPub$originalData$GSE49454$pheno$leukCount

totalCount <- testingObjectPub$originalData$GSE49454$pheno$cd4Count + testingObjectPub$originalData$GSE49454$pheno$cd8Count + testingObjectPub$originalData$GSE49454$pheno$bCount +
  testingObjectPub$originalData$GSE49454$pheno$nkCount  +testingObjectPub$originalData$GSE49454$pheno$eoCount + testingObjectPub$originalData$GSE49454$pheno$neutroCount +
  testingObjectPub$originalData$GSE49454$pheno$lymphCount + testingObjectPub$originalData$GSE49454$pheno$leukCount


testingObjectPub$originalData$GSE49454$pheno$cd4Perc <- testingObjectPub$originalData$GSE49454$pheno$cd4Count/testingObjectPub$originalData$GSE49454$pheno$lymphCount * 100
testingObjectPub$originalData$GSE49454$pheno$cd8Perc <- testingObjectPub$originalData$GSE49454$pheno$cd8Count/testingObjectPub$originalData$GSE49454$pheno$lymphCount * 100
testingObjectPub$originalData$GSE49454$pheno$bPerc <- testingObjectPub$originalData$GSE49454$pheno$bCount/testingObjectPub$originalData$GSE49454$pheno$lymphCount * 100
testingObjectPub$originalData$GSE49454$pheno$nkPerc <- testingObjectPub$originalData$GSE49454$pheno$nkCount/testingObjectPub$originalData$GSE49454$pheno$lymphCount * 100
testingObjectPub$originalData$GSE49454$pheno$eoPerc <- testingObjectPub$originalData$GSE49454$pheno$eoCount/testingObjectPub$originalData$GSE49454$pheno$leukCount * 100
testingObjectPub$originalData$GSE49454$pheno$neutroPerc <- testingObjectPub$originalData$GSE49454$pheno$neutroCount/testingObjectPub$originalData$GSE49454$pheno$leukCount * 100
testingObjectPub$originalData$GSE49454$pheno$lymphPerc <- testingObjectPub$originalData$GSE49454$pheno$lymphCount/testingObjectPub$originalData$GSE49454$pheno$leukCount * 100
# testingObjectPub$originalData$GSE49454$pheno$leukPerc <- testingObjectPub$originalData$GSE49454$pheno$leukCount/totalCount * 100

#There are two studies who have more neutrophils than leukocytes, so something must be wrong. Exclude them. 
excludeMe <- rownames(testingObjectPub$originalData$GSE49454$pheno)[which(testingObjectPub$originalData$GSE49454$pheno$neutroPerc > 100)] 
testingObjectPub$originalData$GSE49454$pheno <- testingObjectPub$originalData$GSE49454$pheno[!row.names(testingObjectPub$originalData$GSE49454$pheno) %in% excludeMe,]
testingObjectPub$originalData$GSE49454$expr <- testingObjectPub$originalData$GSE49454$expr[,colnames(testingObjectPub$originalData$GSE49454$expr) %in% rownames(testingObjectPub$originalData$GSE49454$pheno)]
testingObjectPub$originalData$GSE49454$class <- testingObjectPub$originalData$GSE49454$class[names(testingObjectPub$originalData$GSE49454$class) %in% rownames(testingObjectPub$originalData$GSE49454$pheno)]

gse49454cd4plot <- MetaIntegratorLupus::regressionPlot(sleFilter, testingObjectPub$originalData$GSE49454, continuousVariableColumn = "cd4Perc", "CD4+ T Cell Percentage")
gse49454cd8plot <- MetaIntegratorLupus::regressionPlot(sleFilter, testingObjectPub$originalData$GSE49454, continuousVariableColumn = "cd8Perc", "CD8+ T Cell Percentage")
gse49454bplot <- MetaIntegratorLupus::regressionPlot(sleFilter, testingObjectPub$originalData$GSE49454, continuousVariableColumn = "bPerc", "B Cell Percentage")
gse49454nkplot <- MetaIntegratorLupus::regressionPlot(sleFilter, testingObjectPub$originalData$GSE49454, continuousVariableColumn = "nkPerc", "NK Cell Percentage")
gse49454eoplot <- MetaIntegratorLupus::regressionPlot(sleFilter, testingObjectPub$originalData$GSE49454, continuousVariableColumn = "eoPerc", "Eosinophil Percentage")
gse49454neutroplot <- MetaIntegratorLupus::regressionPlot(sleFilter, testingObjectPub$originalData$GSE49454, 
                                                          continuousVariableColumn = "neutroPerc", "Neutrophil Percentage", correlationCorner = "topLeft")
gse49454lymphplot <- MetaIntegratorLupus::regressionPlot(sleFilter, testingObjectPub$originalData$GSE49454, continuousVariableColumn = "lymphPerc", 
                                                         "Lymphocyte Percentage", correlationCorner = "topRight")
gse49454leukplot <- MetaIntegratorLupus::regressionPlot(sleFilter, testingObjectPub$originalData$GSE49454, continuousVariableColumn = "leukPerc", "Leukocyte Percentage")

# GSE65391
testingObjectPub$originalData$GSE65391$pheno$neutroPerc <- sapply(testingObjectPub$originalData$GSE65391$pheno$characteristics_ch1.22, labelSplit)
testingObjectPub$originalData$GSE65391$pheno$neutroPerc[testingObjectPub$originalData$GSE65391$pheno$neutroPerc %in% c("Data Not Available", "Not Applicable")] <- NA
testingObjectPub$originalData$GSE65391$pheno$neutroPerc <- as.numeric(testingObjectPub$originalData$GSE65391$pheno$neutroPerc)

testingObjectPub$originalData$GSE65391$pheno$lymphPerc <- sapply(testingObjectPub$originalData$GSE65391$pheno$characteristics_ch1.23, labelSplit)
testingObjectPub$originalData$GSE65391$pheno$lymphPerc[testingObjectPub$originalData$GSE65391$pheno$lymphPerc %in% c("Data Not Available", "Not Applicable")] <- NA
testingObjectPub$originalData$GSE65391$pheno$lymphPerc <- as.numeric(testingObjectPub$originalData$GSE65391$pheno$lymphPerc)

testingObjectPub$originalData$GSE65391$pheno$monoPerc <- sapply(testingObjectPub$originalData$GSE65391$pheno$characteristics_ch1.24, labelSplit)
testingObjectPub$originalData$GSE65391$pheno$monoPerc[testingObjectPub$originalData$GSE65391$pheno$monoPerc %in% c("Data Not Available", "Not Applicable")] <- NA
testingObjectPub$originalData$GSE65391$pheno$monoPerc <- as.numeric(testingObjectPub$originalData$GSE65391$pheno$monoPerc)


gse65391lymphplot <- MetaIntegratorLupus::regressionPlot(sleFilter, testingObjectPub$originalData$GSE65391, continuousVariableColumn = "lymphPerc", 
                                                         "Lymphocyte Percentage", correlationCorner = "topRight")
gse65391neutroplot <- MetaIntegratorLupus::regressionPlot(sleFilter, testingObjectPub$originalData$GSE65391, 
                                                          continuousVariableColumn = "neutroPerc", "Neutrophil Percentage", correlationCorner = "topLeft")
gse65391monoplot <- MetaIntegratorLupus::regressionPlot(sleFilter, testingObjectPub$originalData$GSE65391, continuousVariableColumn = "monoPerc", "Monocyte Percentage")

##############
# Training vs. Testing
##############

trainingTesting <- merge(trainingObjectPub$metaAnalysis$pooledResults, testingObjectBlood$metaAnalysis$pooledResults,
                         by="row.names", suffixes = c("Discovery","Validation"))
trainingTestingPlot <- ggplot(trainingTesting[trainingTesting$Row.names %in% c(sleFilter$posGeneNames, sleFilter$negGeneNames),], aes(x=effectSizeDiscovery, y=effectSizeValidation)) + 
  geom_point() + xlab("Discovery Effect Size") + ylab("Validation Effect Size") + geom_hline(yintercept = 0) + geom_vline(xintercept = 0)


#################
# Prospective validation qPCR data
#################
load("prepData/qPCRprospective.RData")
source("additionalScripts/violinPlot.R")
source("additionalScripts/regressionPlot.R")

Dx <- c(experiments.m$experiment.all$firstvisit, experiments.m$experiment.all$healthies)
Dx.factor <- factor(ifelse(grepl("H", Dx), "Adult healthy", ifelse(grepl("C", Dx), "JIA", "SLE")), levels = c("SLE", "Adult healthy", "JIA"))
temp <- data.frame(Meta = experiments.m$experiment.all$Geo.Scores$Meta[Dx, ], Dx = Dx.factor)
prospectiveViolin <- .createViolinPlot(temp, "Dx", "Meta", "Stanford Pediatric SLE Cohort", autoLineBreak = F) 

prospectiveSledai <- data.frame(score  = experiments.m$experiment.all$Geo.Scores.df[experiments.m$experiment.all$firstvisit, "Meta"],
                                continuous = SLEDAI.df[experiments.m$experiment.all$firstvisit, "SLEDAI"])
prospectiveSledaiPlot <- .createRegressionPlot(prospectiveSledai, formattedName = "",  formattedVariableName = "SLEDAI")

#################
# Analyze overlap with other SLE signatures
#################

Pascual <- c("AGRN", "C2", "IFI6", "IFI35", "IRF7", "ISG15", "PLSCR1", "MX1", "MX2", "LY6E", "TAP1", "TRDV3, TRDV1", "TNFRSF10B", "XAF1")
PascualNew <- c("IFI35", "IRF7", "MX1", "MX2", "XAF1", "IFI44L", "OAS2", "IFI44", "LY6E", "AGRN", "IFIT1", "RSAD2", "ISG15", 
                "OASL", "IFIT3", "CCL2", "TDRD7", "PLSCR1", "ACSL1", "TNFSF10", "OAS1", "GBP1", "SERPING1", "FCGR1A", "C2", 
                "TYMP", "IRF9", "MXRA7", "LAMP3", "LGALS3BP", "IFITM3", "TAP1", "IFI6", "APOBEC3G", "GMPR", "TRD", "DLEU1", 
                "COX11", "HNRNPDL", "TTC3", "DAP3", "SORL1", "PRNP", "SLC25A6", "PRR4", "PABPC4", "RAB4A", "CD3G")
Neutrophil <- c("DEFA1", "DEFA3", "DEFA1B", "RNASE2") 
Baechler <- c("CIC", "IFI6", "LGALS3BP", "PLSCR1", "ISG15", "MX1", "LY6E", "OASL", "RNASE2", "APOBEC3C", "SERPING1", "XAF1", "FCGR1B, FCGR1A, FCGR1C")
Genentech <- c("EPSTI1", "HERC5", "LTK")
Meta <- c(sleFilter$posGeneNames, sleFilter$negGeneNames)
PascualLarge <- readxl::read_excel("prepData/mmc5.xlsx", skip = 1)$Symbol

library(gplots)
pdf("plots/listOverlaps.pdf")
venn(list(Meta=Meta, PascualLarge=PascualLarge))
venn(list(Meta=Meta, Pascual=Pascual))
venn(list(Meta=Meta, Neutrophil=Neutrophil))
venn(list(Meta=Meta, Baechler=Baechler))
venn(list(Meta=Meta, Genentech=Genentech))
venn(list(Meta=Meta, Pascual=PascualNew, PascualLarge=PascualLarge, Baechler=Baechler, Genentech=Genentech))
venn(list(Meta=Meta, Pascual=PascualNew, Baechler=Baechler, Genentech=Genentech))
dev.off()

violinTheme <- theme(axis.title.x = element_blank(), axis.text.x=element_text(angle=20, vjust=1, hjust=1))
sleY <- ylab("SLE MetaScore")


pdf("plots/figures2-5.pdf", width=15, height=15)
plot_grid(plot_grid(trainingHeatmap + ggtitle("Discovery") + theme(legend.position = "left") + 
                      theme(plot.margin = unit(c(0,0,0,0.03), "npc")), 
                    testingHeatmap + ggtitle("Validation") + guides(fill=F) + theme(plot.margin = unit(c(0,0,0,0.155), "npc")), 
                    extendedTestingHeatmap + ggtitle("Extended Validation") + guides(fill=F),
                    ncol=1, labels = "AUTO", label_size=30, 
                    rel_heights = c(0.2,0.2,0.6), align="v"),
          plot_grid(trainingROC + coord_fixed(), testingROC+ coord_fixed(),
                    ncol=1, labels=c("D","E"), label_size=30), ncol=2, rel_heights = c(0.6,0.4))
plot_grid(gse38351plot +violinTheme + sleY, gse22098plot + violinTheme + sleY, 
          gse32591glomPlot + violinTheme + sleY, gse36700plot + violinTheme + sleY, 
          GSE4588CD4Tplot + violinTheme + sleY, GSE10325Bplot + violinTheme + sleY, ncol=2, 
          labels="AUTO", label_size=30, align="h")
plot_grid(NULL, NULL, NULL,
          sleMetaCorPlot, 
          hexPlot(gse88884sledai)+ scale_x_continuous(limits=c(0,40)) + sleY , 
          hexPlot(gse65391c3) + sleY, ncol=3, labels=c(rep(NA,3),c("A","B","C")), 
          label_size=30, nrow=3, rel_heights = c(0.8,1,0.8))
plot_grid(NULL, NULL, 
          prospectiveViolin + violinTheme + sleY, prospectiveSledaiPlot + sleY, 
          ncol=2, nrow=3,  rel_heights = c(0.5,1,0.5),
          labels=c(NA, NA,"A","B"), label_size=30)
dev.off()


pdf("plots/figureSuppl.pdf", width=15, height=15)
plot_grid(trainingTestingPlot, ncol=2, nrow=2)
plot_grid(gse29536plot + violinTheme + sleY,
          gse8650plot + violinTheme + sleY, ncol=1, labels="AUTO")
plot_grid(gse32591tubPlot + violinTheme + sleY,
          gse52471plot + violinTheme + sleY, ncol=2, nrow=2, labels="AUTO")
plot_grid(plot_grid(GSE10325CD4Tplot + violinTheme + sleY, GSE51997CD4Tplot + violinTheme + sleY,
                    GSE55447CD4Tplot + violinTheme + sleY, ncol=3, labels="AUTO"),
          GSE55447CD8Tplot + violinTheme + sleY,
          plot_grid(GSE4588Bplot + violinTheme + sleY, GSE55447Bplot + violinTheme + sleY,
                    GSE30153plot + violinTheme + sleY, ncol=3, labels=c("E","F","G")),
          ncol=1, labels=c("A","D","E"))
plot_grid(gse49454neutroplot + sleY, gse65391neutroplot + sleY, gse49454lymphplot + sleY, gse65391lymphplot + sleY, 
          gse49454cd4plot + sleY, gse49454cd8plot + sleY , gse49454bplot + sleY,  gse49454nkplot + sleY, 
          gse49454eoplot  + sleY,gse65391monoplot + sleY, ncol=4, labels="AUTO")
plot_grid(hexPlot(gse49454sledai) + scale_x_continuous(limits=c(0,40)) + sleY, 
          hexPlot(gse65391sledai) + scale_x_continuous(limits=c(0,40)) + sleY, 
          gse27427sledai + scale_x_continuous(limits=c(0,40)) + sleY, 
          gse8650sledai + scale_x_continuous(limits=c(0,40)) + sleY , 
          hexPlot(gse65391esr) + sleY, 
          hexPlot(gse65391c4) + sleY, ncol=3, nrow=3,  labels="AUTO")
extendedTestingROC
dev.off()

library(readr)
library(ggplot2)
library(plotly)
library(MetaIntegratorPrivateLupus)
library(reshape2)
library(scales)
library(cowplot)
library(Hmisc)
library(dplyr)
library(ggpubr)
library(grid)
library(gtable)
library(gridExtra)
splitFun <- function(curStr, index=2, splitStr=": ") { strsplit(as.character(curStr), splitStr)[[1]][[index]]}
esThresh <- 0.8

##########
#Load the recovered file from Chris' meta-analysis
##########
load("prepData/cbolenMeta.RData")
load("RData/trainingObjectPub.RData")
load("RData/testingObjectPub.RData")
load("RData/curFilter.RData")
sleFilter <- curFilter

##########
#Neutrophil levels for every gene
##########
neutroData <- readr::read_csv("prepData/allNeutrophilGenes.csv")

##############
# Examine SLE signature vs. Bolen IFN meta-analysis
##############
sleIfn <- merge(trainingObjectPub$metaAnalysis$pooledResults, cbolenMeta$metaAnalysis$pooledResults, by="row.names", suffixes = c("SLE","IFN"), all.x=T)
sleIfnNeutro <- merge(sleIfn, neutroData, by.x = "Row.names",by.y="geneName", suffixes = c("", "Neutro"), all.x = T)

tableS1 <- sleIfnNeutro
tableS1$geneName <- tableS1$Row.names
tableS1 <- tableS1[tableS1$geneName %in% c(sleFilter$posGeneNames, sleFilter$negGeneNames),]
colnames(tableS1)[30:41] <- paste(colnames(tableS1)[30:41], "Neutro",sep="")
tableS1 <- tableS1[,c("geneName", "effectSizeSLE", "effectSizeIFN", "gNeutro", "effectSizeFDRSLE", 
                      "effectSizeFDRIFN","se_gNeutro")]
colnames(tableS1)[c(4,7)] <- c("effectSizeNeutro", "effectSizeStandardErrorNeutro")

tableS1 <- tableS1[order(tableS1$effectSizeSLE, decreasing = T),]
tableS1$isIFN <- !is.na(tableS1$effectSizeIFN) & abs(tableS1$effectSizeIFN) >= esThresh
tableS1$isNeutro <- !is.na(tableS1$effectSizeNeutro) &  abs(tableS1$effectSizeNeutro) >= esThresh
for(i in 1:nrow(tableS1)) {
  for(j in c("isIFN","isNeutro")) {
    if(tableS1[i,j]) {
      tableS1[i,j] <- "X"
    } else {
      tableS1[i,j] <- ""
    }
  }
}
tableS1[,2:7] <- signif(tableS1[,2:7], digits = 3)

##############
# Create Different Filters for IFN, Neutro, and Non
##############
#IFN filter
sleIfnFilter <- sleFilter
sleIfnFilter$posGeneNames <- sleIfnFilter$posGeneNames[sleIfnFilter$posGeneNames %in% sleIfn$Row.names[sleIfn$effectSizeIFN >= esThresh]]
sleIfnFilter$negGeneNames <- sleIfnFilter$negGeneNames[sleIfnFilter$negGeneNames %in% sleIfn$Row.names[sleIfn$effectSizeIFN <= -esThresh]]
sleIfnFilter$filterDescription <- paste("SLE signature genes with |IFN ES| >", esThresh)

#non-IFN filter
sleNonIfnFilter <- sleFilter
sleNonIfnFilter$posGeneNames <- sleNonIfnFilter$posGeneNames[!(sleNonIfnFilter$posGeneNames %in% sleIfnFilter$posGeneNames)]
sleNonIfnFilter$negGeneNames <- sleNonIfnFilter$negGeneNames[!(sleNonIfnFilter$negGeneNames %in% sleIfnFilter$negGeneNames)]
sleNonIfnFilter$filterDescription <- paste("SLE signature genes with |IFN ES| <", esThresh)

#Neutrophil, non-IFN filter
sleNeutroFilter <- sleNonIfnFilter
sleNeutroFilter$posGeneNames <- sleNeutroFilter$posGeneNames[sleNeutroFilter$posGeneNames %in% sleIfnNeutro$Row.names[sleIfnNeutro$g >= esThresh]]
sleNeutroFilter$negGeneNames <- sleNeutroFilter$negGeneNames[sleNeutroFilter$negGeneNames %in% sleIfnNeutro$Row.names[sleIfnNeutro$g <= -esThresh]]
sleNeutroFilter$filterDescription <- paste("SLE signature genes with |Neutro ES| >", esThresh,"and |IFN ES| <", esThresh)

#Mystery genes 
sleMysteryFilter <- sleFilter
sleMysteryFilter$posGeneNames <- setdiff(sleMysteryFilter$posGeneNames, c(sleIfnFilter$posGeneNames, sleNeutroFilter$posGeneNames))
sleMysteryFilter$negGeneNames <- setdiff(sleMysteryFilter$negGeneNames, c(sleIfnFilter$negGeneNames, sleNeutroFilter$negGeneNames))
sleMysteryFilter$filterDescription <- paste("SLE signature genes with |Neutro ES| <", esThresh,"and |IFN ES| <", esThresh)

save(sleFilter, sleIfnFilter, sleNonIfnFilter, sleNeutroFilter, sleMysteryFilter, file="RData/filterObjects.RData")
load("RData/filterObjects.RData")

##############
# ROC and SLEDAI correlation Data for all filters
##############
# SLEDAI correlation
sledaiCorFrame <- data.frame()
for(filterName in c("sleFilter","sleIfnFilter", "sleNonIfnFilter", "sleMysteryFilter", "sleNeutroFilter")) {
  thisFilter <- get(filterName)
  for(datasetName in c("GSE27427","GSE8650...Complete","GSE49454","GSE65391","GSE88884")) {
    sledaiCorFrame <- rbind(sledaiCorFrame, data.frame(datasetName=datasetName, filterName=filterName,
                                                     sledaiCor=cor(testingObjectPub$originalData[[datasetName]]$pheno$sledai,
                                                                   MetaIntegratorLupus::calculateScore(thisFilter, datasetObject = testingObjectPub$originalData[[datasetName]]),
                                                                   method = "spearman", use = "pairwise.complete.obs")))
  }
}
sledaiCorTable <- dcast(sledaiCorFrame, datasetName ~ filterName, value.var = "sledaiCor")
sledaiCorTable[,2:ncol(sledaiCorTable)] <- round(sledaiCorTable[,2:ncol(sledaiCorTable)], digits=3)

#ROC data
summaryAUCFrame <- data.frame()
for(filterName in c("sleFilter","sleIfnFilter", "sleNonIfnFilter")) {
  thisFilter <- get(filterName)
for(metaObjectName in c("trainingObjectPub", "testingObjectBlood")) {
  metaObject <- get(metaObjectName)
  curAUC <- summaryROCCalc(metaObject = metaObject, filterObject = thisFilter)
  curAUC$filterName <- filterName
  curAUC$metaObject <- metaObjectName

  summaryAUCFrame <- rbind(summaryAUCFrame, curAUC)
}
}
summaryAUCTable <- dcast(summaryAUCFrame, metaObject ~ filterName, value.var = "AUC")
summaryAUCTable[,2:ncol(summaryAUCTable)] <- round(summaryAUCTable[,2:ncol(summaryAUCTable)], digits=3)
readr::write_tsv(summaryAUCTable, path = "ifnMeta/aucTable.tsv")


summaryAUCTable <- summaryAUCTable[,c("metaObject","sleFilter", "sleIfnFilter", "sleNonIfnFilter")]
sledaiCorTableFormatted <- sledaiCorTable[,c("datasetName","sleFilter", "sleIfnFilter", "sleNonIfnFilter")]
colnames(sledaiCorTableFormatted) <- c("Dataset", "SLE MetaSignature", "IFN SLE Genes", "non-IFN SLE Genes")
sledaiCorTableFormatted$Dataset <- as.character(sledaiCorTableFormatted$Dataset)
sledaiCorTableFormatted$Dataset[[2]] <- "GSE8650"
sledaiCorTableFormatted$Dataset <- paste(c("Neutrophils-", "PBMCs-", "Whole Blood-", "Whole Blood-", "PBMCs-"),
                                         sledaiCorTableFormatted$Dataset)
colnames(summaryAUCTable) <- c("Meta-Analysis", "SLE MetaSignature", "IFN SLE Genes", "non-IFN SLE Genes")
summaryAUCTable$`Meta-Analysis` <- as.character(summaryAUCTable$`Meta-Analysis`)
summaryAUCTable$`Meta-Analysis` <- c("Discovery","Validation")
summaryAUCTable <- summaryAUCTable[c(2,1),]

sledaiCorTablePlot <- tableGrob(sledaiCorTableFormatted, rows=NULL, theme = ttheme_default(base_size = 20,
                                                                                  padding = unit(c(10,10), "mm")))
summaryAUCTablePlot <- tableGrob(summaryAUCTable, rows=NULL, theme = ttheme_default(base_size = 20,
                                 padding = unit(c(10,10), "mm")))

save(summaryAUCTablePlot, sledaiCorTablePlot, sledaiCorTable, sledaiCorTableFormatted, summaryAUCTable, file="RData/Figure6Data.RData")

load("RData/Figure6Data.RData")
sumAUCTitle <- textGrob("Summary AUC (SLE vs. Healthy)",gp=gpar(fontsize=30))
padding <- unit(10,"mm")
summaryAUCTablePlot2 <- gtable_add_rows(
  summaryAUCTablePlot, 
  heights = grobHeight(sumAUCTitle) + padding,
  pos = 0)
summaryAUCTablePlotTitle <- gtable_add_grob(summaryAUCTablePlot2, 
                                            sumAUCTitle, 1, 1, 1, 4)

sledaiCorTitle <- textGrob("Correlation of SLEDAI with Score",gp=gpar(fontsize=30))
padding <- unit(5,"mm")
sledaiCorTablePlot2 <- gtable_add_rows(
  sledaiCorTablePlot, 
  heights = grobHeight(sledaiCorTitle) + padding,
  pos = 0)
sledaiCorTablePlotTitle <- gtable_add_grob(sledaiCorTablePlot2, 
                                           sledaiCorTitle, 1, 1, 1, 4)


##############
# Neutro Data
##############
immNeuts <- MetaIntegrator::getGEOData(c("GSE19556","GSE42519","GSE49883"))

hemato <- MetaIntegrator::getGEOData(c("GSE69408", "GSE77439", "GSE98633", "GSE98791"))

netNeuts <- MetaIntegrator::getGEOData(c("GSE80489"))
save(immNeuts, hemato, netNeuts, file="RData/neutObjects.RData")
load("RData/neutObjects.RData")

# GSE80849
treatmentVec <- netNeuts$originalData$GSE80489$pheno$source_name_ch1
treatmentVec <- gsub("Human neutrophils treated with","",treatmentVec)
treatmentVec <- gsub(" \\(","\n\\(", treatmentVec)
treatmentVec <- gsub(")",")\n", treatmentVec)
treatmentVec <- factor(treatmentVec, levels=unique(treatmentVec)[1:6])
treatmentOnly <- gsub("\n for [0-9]+ mins", "",treatmentVec)
treatmentOnly <- factor(treatmentOnly, levels=unique(treatmentOnly)[1:6])
treatmentOnly <- recode(treatmentOnly, " DMSO\n(-ve control)" = "DMSO (Control)",
                        " PMA\n(25 nM)" = "PMA (Nox-dependent NETosis)",
                        " A23187\n(4 uM)" = "A23187 (Nox-independent NETosis)")
netNeuts$originalData$GSE80489$pheno$treatmentOnly <- treatmentOnly

#GSE42519
cellType <- immNeuts$originalData$GSE42519$pheno$title
cellType <- sapply(as.character(cellType), splitFun, index=1, splitStr=" ")
cellType <- factor(cellType, levels=c("HSC", "MPP", "CMP", "GMP", "early_PM", "late_PM", 
                                      "MY", "MM","BC", "PMN", "MEP"))
cellType <- recode(cellType, "HSC" = "Hematopoietic Stem Cells",
                   "MPP" = "Multipotent Progenitors", "CMP" = "Common Myeloid Progenitors",
                   "GMP" = "Granulocyte Macrophage Progenitors", "early_PM" = "Early Promyelocytes",
                   "late_PM" = "Late Promyelocytes", "MY" = "Myelocytes", "MM" = "Metamyelocytes",
                   "BC" = "Band Cells", "PMN" = "Polymorphonuclear Neutrophils",
                   "MEP" = "Megakaryocyte Erytherocyte Progenitors")
immNeuts$originalData$GSE42519$pheno$cellType <- cellType

cellFactors <- immNeuts$originalData$GSE19556_GPL96$pheno$source_name_ch1
cellFactors <- factor(cellFactors, levels = c("myeloblasts", "promyelocytes", 
                                              "bone marrow neutrophils", 
                                              "peripheral blood neutrophils"))
cellFactors <- recode(cellFactors,
                      "myeloblasts" = "Myeloblasts",
                      "promyelocytes" = "Promyelocytes",
                      "bone marrow neutrophils" = "Bone Marrow Neutrophils",
                      "peripheral blood neutrophils" = "Peripheral Blood Neutrophils")
immNeuts$originalData$GSE19556_GPL96$pheno$source_name_ch1 <- cellFactors

cellFactors <- immNeuts$originalData$GSE49883$pheno$characteristics_ch1.3
## Recoding cellFactors
cellFactors <- fct_recode(cellFactors,
                          "CMP" = "cell type: CMP cells",
                          "GMP" = "cell type: GMP cells",
                          "PMC" = "cell type: PMC cells",
                          "PMN" = "cell type: PMN cells")
immNeuts$originalData$GSE49883$pheno$characteristics_ch1.3 <- cellFactors

##############
# Heavy metal data
##############
cadmium <- getGEOData(c("GSE52404", "GSE31286", "GSE20320", "GSE26828", "GSE58431"))

ratMouseCadmium <- getGEOData(c("GSE73744", "GSE65198", "GSE59906", "GSE88739", "GSE83326", "GSE57811"))

zinc <- getGEOData(c("GSE49657", "GSE33174", "GSE6972", "GSE2964", "GSE2111", "GSE76510", "GSE60408"))

copper <- getGEOData(c("GSE9539"))

save(cadmium, zinc, ratMouseCadmium, copper, file="RData/heavyMetals.RData")
load("RData/heavyMetals.RData")

#GSE6972
zinc$originalData$GSE6972$pheno$treatment <- gsub(" [ABCD]$","", zinc$originalData$GSE6972$pheno$title)
a549Vec <- setdiff(1:nrow(zinc$originalData$GSE6972$pheno), grep("A549", zinc$originalData$GSE6972$pheno$treatment))
a549 <- zinc$originalData$GSE6972
a549$pheno <- a549$pheno[a549Vec, ]
a549$expr <- a549$expr[,a549Vec ]
a549$class <- a549$class[a549Vec]
a549$pheno$treatment <- factor(a549$pheno$treatment, levels=unique(a549$pheno$treatment))
treatmentSimple <- as.character(a549$pheno$treatment)
treatmentSimple[10:12] <- "PCI 5002"
treatmentSimple <- factor(treatmentSimple, levels=unique(treatmentSimple))
treatmentSimple <- recode(treatmentSimple, "PCI 5002" = "Soluble Zinc")
a549$pheno$treatmentSimple <- treatmentSimple


#GSE52404
cadmiumAdaptation <- sapply(cadmium$originalData$GSE52404$pheno$characteristics_ch1, splitFun)
isCadmiumAdapted <- gsub("[0-9]+$","",cadmiumAdaptation)
isCadmiumAdapted <- factor(isCadmiumAdapted, levels=unique(isCadmiumAdapted))
isCadmiumAdapted <- recode(isCadmiumAdapted,
                           "MCF" = "Control", "cadmium MCF7-Cd" = "Cadmium")
cadmium$originalData$GSE52404$pheno$isCadmiumAdapted <- isCadmiumAdapted

##############
# NK cell data
##############
nkData <- getGEOData(c("GSE63829"))
humanToMouse <- readr::read_tsv("humanToMouse.txt", col_names = F)
colnames(humanToMouse)[c(1,5)] <- c("humanGene", "mouseGene")
humanToMouse$mouseGene <- toupper(humanToMouse$mouseGene)

mapFunction <- function(curKey) {
  newKey <- rep(NA, length(curKey))
  for(i in 1:length(newKey)){
    mouseGene <- curKey[[i]]
    humanGenes <- humanToMouse[!is.na(mouseGene) & mouseGene != "NA" & humanToMouse$mouseGene==mouseGene,]$humanGene
    if(length(humanGenes) > 0) {
      newKey[[i]] <- paste(humanGenes, sep="//", collapse="//")
    }
  }
  return(newKey)
}
nkData$originalData$GSE63829$keys <- mapFunction(nkData$originalData$GSE63829$keys)
save(nkData, file="RData/nkData.RData")
load("RData/nkData.RData")

##############
# SLE/IFN/Neutro Plots
##############
gg_color_hue <- function(n) {
  hues = seq(15, 375, length = n + 1)
  hcl(h = hues, l = 65, c = 100)[1:n]
}

sleVsIFNPlot <- ggplot(sleIfn, aes(y=effectSizeSLE, x=effectSizeIFN)) + 
  ylab("SLE Effect Size") + xlab("IFN Effect Size") + geom_hex(bins=50) + 
  scale_fill_continuous(low = "gray85", high = "black", trans = log10_trans(), name="Number of Genes") +
  geom_vline(xintercept=esThresh , color="grey", lwd=2,lty=2)+ 
  geom_vline(xintercept=-esThresh, color="grey", lwd=2,lty=2)+
  geom_hline(yintercept=1 , color="grey", lwd=2,lty=2)+ 
  geom_hline(yintercept=-1, color="grey", lwd=2,lty=2)+
  geom_point(data=sleIfn[sleIfn$Row.names %in% c(sleFilter$posGeneNames, sleFilter$negGeneNames),], color=gg_color_hue(3)[1], size=3) +
  geom_point(data=sleIfn[sleIfn$Row.names %in% c(sleNonIfnFilter$posGeneNames, sleNonIfnFilter$negGeneNames),], color=gg_color_hue(3)[2], size=3) +
  theme(text = element_text(size=20), axis.title=element_text(size=24),  legend.position = c(0.05,0.95), 
        legend.justification = c(0,1), legend.background = element_rect(fill=F)) 


ifnVolcanoPlot <- ggplot(sleIfn, aes(y=effectSizeFDRIFN, x=effectSizeIFN)) + 
  ylab("IFN Effect Size FDR") + xlab("IFN Effect Size")+
  geom_hex(bins=50) + scale_y_log10() +
  scale_fill_continuous(low = "gray85", high = "black", trans = log10_trans(), name="Number of Genes") +
  geom_hline(yintercept=.05 , color="grey", lwd=2,lty=2)+ 
  geom_vline(xintercept=esThresh , color="grey", lwd=2,lty=2)+ 
  geom_vline(xintercept=-esThresh, color="grey", lwd=2,lty=2)+ 
  geom_point(data=sleIfn[sleIfn$Row.names %in% c(sleFilter$posGeneNames, sleFilter$negGeneNames),], color=gg_color_hue(3)[1], size=3)+
  geom_point(data=sleIfn[sleIfn$Row.names %in% c(sleNonIfnFilter$posGeneNames, sleNonIfnFilter$negGeneNames),], color=gg_color_hue(3)[2], size=3) +
  theme(text = element_text(size=20), axis.title=element_text(size=24),  legend.position = c(0.05,0.05), 
        legend.justification = c(0,0), legend.background = element_rect(fill=F)) 

ifnVsNeutroPlot <- ggplot(sleIfnNeutro, aes(x=g, y=effectSizeIFN)) + 
  xlab("Neutrophil Effect Size") + ylab("IFN Effect Size") + geom_hex(bins=50) + 
  scale_fill_continuous(low = "gray85", high = "black", trans = log10_trans(), name="Number of Genes") +
  geom_hline(yintercept=esThresh , color="grey", lwd=2,lty=2)+ 
  geom_hline(yintercept=-esThresh , color="grey", lwd=2,lty=2)+ 
  geom_vline(xintercept=esThresh , color="grey", lwd=2,lty=2)+ 
  geom_vline(xintercept=-esThresh , color="grey", lwd=2,lty=2)+ 
  geom_point(data=sleIfnNeutro[sleIfnNeutro$Row.names %in% c(sleFilter$posGeneNames, sleFilter$negGeneNames),], color=gg_color_hue(3)[1], size=3)+
  geom_point(data=sleIfnNeutro[sleIfnNeutro$Row.names %in% c(sleNonIfnFilter$posGeneNames, sleNonIfnFilter$negGeneNames),], color=gg_color_hue(3)[2], size=3) +
  geom_point(data=sleIfnNeutro[sleIfnNeutro$Row.names %in% c(sleMysteryFilter$posGeneNames, sleMysteryFilter$negGeneNames),], color=gg_color_hue(3)[3],size=3)+
  theme(text = element_text(size=20), axis.title=element_text(size=24),  legend.position = c(0.05,0.95), 
        legend.justification = c(0,1), legend.background = element_rect(fill=F)) 

##############
# Heavy Metal Plots
##############
gse6972plot <- violinPlot(filterObject = sleMysteryFilter, datasetObject = a549, labelColumn = "treatmentSimple", 
                          comparisonMethod = "t.test", autoLineBreak = F) 

gse52404plot <- violinPlot(filterObject = sleMysteryFilter, datasetObject = cadmium$originalData$GSE52404, 
                           labelColumn = "isCadmiumAdapted", comparisonMethod = "t.test", autoLineBreak = F) 

##############
# Neutro Plots
##############
diseaseLabel <- testingObjectPub$originalData$GSE26975$pheno$source_name_ch1
diseaseLabel <- recode(diseaseLabel,
                       "Control neutrophil from healthy human" = "Control Neutrophil",
                       "LDG from lupus patient" = "SLE Low-Density Granulocyte",
                       "Neutrophil from lupus patient" = "SLE Neutrophil")
testingObjectPub$originalData$GSE26975$pheno$source_name_ch1 <- diseaseLabel
gse26975neutro <- violinPlot(filterObject = sleNonIfnFilter, datasetObject = testingObjectPub$originalData$GSE26975, 
                             labelColumn = "source_name_ch1", comparisonMethod = "t.test", autoLineBreak = F) 

gse80489plot <- violinPlot(filterObject = sleNonIfnFilter, datasetObject = netNeuts$originalData$GSE80489, 
                           labelColumn = "treatmentOnly", comparisonMethod = "t.test", autoLineBreak = F) 

immNeuts$originalData$GSE42519$pheno$neutroScore <- calculateScore(datasetObject =  immNeuts$originalData$GSE42519, 
                                                                   filterObject = sleNonIfnFilter)
gse42519plot <- violinPlot(filterObject = sleNonIfnFilter, datasetObject = immNeuts$originalData$GSE42519, 
                           labelColumn = "cellType", comparisonMethod = "wilcox.test", pairwiseComparisons = F, autoLineBreak = F) +
  theme(text = element_text(size=20), axis.title=element_text(size=24), 
        axis.text.x = element_text(angle = 20, size=20, hjust=0.8, vjust=0.9), legend.position = c(0.05,0.95), 
        legend.justification = c(0,1), legend.background = element_rect(fill=F)) 

gse19556plot <- violinPlot(filterObject = sleNonIfnFilter, immNeuts$originalData$GSE19556_GPL96, 
                           labelColumn = "source_name_ch1", comparisonMethod = "t.test", autoLineBreak = F)

gse49883plot <- violinPlot(curFilter, immNeuts$originalData$GSE49883, 
                           labelColumn = "characteristics_ch1.3", comparisonMethod = "t.test", autoLineBreak = F)

##############
# NK cell plots
##############
gse63829plot <- violinPlot(filterObject = sleMysteryFilter, datasetObject = nkData$originalData$GSE63829, 
                           labelColumn = "source_name_ch1", comparisonMethod = "t.test", autoLineBreak = F) 

##############
# Flow Diagram figures
##############
flow1 <- ggdraw() + draw_image("plots/flow1.pdf",scale=0.9)
flow2 <- ggdraw() + draw_image("plots/flow2.pdf")
flowall <- ggdraw() + draw_image("plots/flow_all.pdf", scale=0.9)

##############
# Build Figures
##############
outputDir <- "plots/"
labelFontface = "bold"
violinTheme <- theme(axis.title.x = element_blank(), axis.text.x=element_text(angle=20, vjust=1, hjust=1))
figure6 <- plot_grid(plot_grid(NULL, plot_grid(flow1, sleVsIFNPlot,nrow=2, rel_heights = c(0.2,0.8)), 
                               ncol=3, labels = c("A", NA, NA), 
                               label_size=30, label_fontface = labelFontface, rel_widths = c(0.2,0.6,0.2)),
                     summaryAUCTablePlotTitle, sledaiCorTablePlotTitle,
                     ncol=1, align="h", nrow=3, rel_heights = c(1,0.4,0.6),
                     labels=c(NA, "B","C"), label_size=30, label_fontface = labelFontface)
figure7 <- plot_grid(plot_grid(gse26975neutro + violinTheme+ ylab("non-IFN SLE MetaScore") + theme(plot.margin = unit(c(0,0,0,0.1), "npc")),
                               gse80489plot + violinTheme+ ylab("non-IFN SLE MetaScore"), ncol=2, labels=c("A","B"), 
                               align="h", label_size=30, label_fontface = labelFontface),
                     gse42519plot + violinTheme + ylab("non-IFN SLE MetaScore")+ theme(plot.margin = unit(c(0,0,0,0.1), "npc")),
                     ncol=1, labels = c(NA,"C"), label_size=30, label_fontface = labelFontface)
figure8 <- plot_grid(NULL, NULL, plot_grid(flowall, ifnVsNeutroPlot + coord_fixed(),  ncol=1, rel_heights = c(0.2,0.8)),
                     plot_grid(NULL, NULL, gse52404plot + violinTheme+ ylab("Under-appreciated SLE MetaScore"), 
                               gse6972plot+ violinTheme+ ylab("Under-appreciated SLE MetaScore"), ncol=2, nrow=3, labels=c("B","C", rep(NA,4)),
                               label_size=30, label_fontface = labelFontface, rel_heights = c(0.2,1,0.2)), 
                     labels = c(rep(NA,2),"A",rep(NA,3)), label_size=30, label_fontface = labelFontface, ncol=2, nrow=3, 
                     rel_heights = c(0.5,1,0.5))

neutroSup <- plot_grid(gse19556plot+ ylab("SLE non-IFN MetaScore") + violinTheme,
                       gse49883plot+ ylab("SLE non-IFN MetaScore") + violinTheme, 
                       labels = capitalize(letters[1:2]), 
                       label_size=30, label_fontface = labelFontface, ncol=2, nrow=2)
sleVolcanoSup <- plot_grid(ifnVolcanoPlot, nrow=2, ncol=2, labels=c(NA,NA,NA,NA))

pdf(paste(outputDir, "figure6-8.pdf", sep=""), width=15, height=15)
figure6
figure7
figure8
dev.off()

pdf(paste(outputDir, "nonIfnSuppl.pdf", sep=""), width=15, height=15)
neutroSup
sleVolcanoSup
dev.off()

write_tsv(tableS1, paste(outputDir, "tableS1.tsv"))
heatmapPlot(metaObject=trainingObjectPub, filterObject=sleNonIfnFilter)

library(rmeta)
library(MetaIntegratorPrivateLupus)
source("MetaIntegrator/R/metaAnalysisFoundation.R")
load("RData/testingObjectPub.RData")
load("RData/curFilter.RData")
sleFilter <- curFilter


#################
# Set up the meta-analysis functions for calculating fisher Z
#################

fisherZ <- function(r) {
  return(0.5 * log((1+r)/(1-r)))
}
fisherSE <- function(n) {
  return(1/(n-3))
}
unFisherZ <- function(z) {
  if(is.nan(z)) { return(0) }
  return( (exp(2*z)-1)/(exp(2*z)+1))
}

#################
# Set up IFN signatures
#################

modFilter <- function(sleFilter, curIFN) {
  ifnFilter <- sleFilter
  nonIfnFilter <- sleFilter
  
  ifnFilter$posGeneNames <- intersect(sleFilter$posGeneNames, curIFN)
  ifnFilter$negGeneNames <- intersect(sleFilter$negGeneNames, curIFN)
  
  nonIfnFilter$posGeneNames <- setdiff(sleFilter$posGeneNames, curIFN)
  nonIfnFilter$negGeneNames <- setdiff(sleFilter$negGeneNames, curIFN)
  
  ifnFilter$filterDescription <- paste(ifnFilter$filterDescription, "IFN related only.")
  nonIfnFilter$filterDescription <- paste(nonIfnFilter$filterDescription, "non-IFN related only.")
  return(list(ifn=ifnFilter, nonIfn = nonIfnFilter))
}

interferomeGenes <- rbind(readr::read_tsv("prepData/negGenes_interferome.tsv"), readr::read_tsv("prepData/posGenes_interferome.tsv"))
interferomeFilters <- modFilter(sleFilter, interferomeGenes$`Gene Name`)

smallGenes <- rbind(readr::read_csv("prepData/ifnGenes_manual.csv"))
smallFilter <- modFilter(sleFilter, smallGenes$C2)

################
# Calculate fisher Z and perform meta-analysis
#############


sledaiCorFrame <- data.frame()
ifnList <- list("SLE Meta" = sleFilter, "SLE IFN meta-analysis induced" = sleIfnFilter, "SLE IFN meta-analysis non-induced" = sleNonIfnFilter,
                "SLE Interferome"= interferomeFilters$ifn, "SLE non-Interferome" = interferomeFilters$nonIfn, 
                "SLE IFN manual list" = smallFilter$ifn, "SLE non-IFN manual list" = smallFilter$nonIfn)
for(filterName in names(ifnList)) {
  thisFilter <- ifnList[[filterName]]
  for(datasetName in c("GSE27427","GSE8650...Complete","GSE49454","GSE65391","GSE88884")) {
    corTest=cor.test(testingObjectPub$originalData[[datasetName]]$pheno$sledai,
                     calculateScore(thisFilter, datasetObject = testingObjectPub$originalData[[datasetName]]),
                     method = "spearman", use = "pairwise.complete.obs")
    sledaiCorFrame <- rbind(sledaiCorFrame, data.frame(datasetName=datasetName, filterName=filterName,
                                                       sledaiCor=corTest$estimate, 
                                                       sledaiN=sum(!is.na(testingObjectPub$originalData[[datasetName]]$pheno$sledai))))
  }
  curSubset <- sledaiCorFrame[sledaiCorFrame$filterName == filterName,]
  rownames(curSubset) <- curSubset$datasetName
  corFrame <- fisherZ(curSubset[,"sledaiCor"])
  corSEFrame <- fisherSE(curSubset[,"sledaiN"])
  
  corMetaRes <- .pool.inverseVar(t(as.matrix(corFrame)), t(as.matrix(corSEFrame)), method="random")
  corMetaRes <- as.data.frame(corMetaRes)
  corMetaRes$corMeta <- unFisherZ(corMetaRes$summary)
  sledaiCorFrame <- rbind(sledaiCorFrame, data.frame(datasetName="Meta-Correlation", filterName=filterName,
                                                     sledaiCor=corMetaRes$corMeta, 
                                                     sledaiN=sum(curSubset$sledaiN)))
}
sledaiCast <- dcast(sledaiCorFrame, datasetName ~ filterName, value.var = "sledaiCor")
readr::write_csv(sledaiCast, path = "ifnGenes/ifnSledaiTable.csv")

sledaiCorFrame <- sledaiCorFrame[sledaiCorFrame$filterName == "SLE Meta",]

sledaiCorFrame$datasetName <- as.character(sledaiCorFrame$datasetName)
sledaiCorFrame$datasetName[2] <- "GSE8650"
boxColor = "blue"; whiskerColor = "lightblue"; zeroLineColor = "black"; summaryColor = "orange"; textColor = "black"
pdf("plots/correlationForestPlot.pdf", width=8, height=5)
metaplot(mn=corFrame, se=corSEFrame, labels=paste(c("Neutrophils", "PBMCs", rep("Whole Blood",3)), sledaiCorFrame$datasetName, sep=": "),
         summn =corMetaRes$corMeta, sumse=corMetaRes$se.summary, 	sumnn = 1/corMetaRes$se.summary^2,
         xlab="Spearman Correlation", ylab="",
         colors=meta.colors(box = boxColor, lines = whiskerColor, 
                            zero = zeroLineColor, summary = summaryColor, text = textColor), xlim=c(-0.01,1))
dev.off()

sledaiCorFrame$sledaiSE <- corSEFrame
sledaiCorFrame <- rbind(sledaiCorFrame, data.frame(datasetName="Summary", filterName="Summary", 
                                                   sledaiCor= corMetaRes$corMeta, sledaiN= NA, sledaiSE=corMetaRes$se.summary))
## Reordering sledaiCorFrame$datasetName

sledaiCorFrame$datasetName<- forcats::fct_recode(sledaiCorFrame$datasetName,
                                                 "Neutrophils: GSE27427" = "GSE27427",
                                                 "PBMCs: GSE8650" = "GSE8650",
                                                 "Whole Blood: GSE49454" = "GSE49454",
                                                 "Whole Blood: GSE65391" = "GSE65391",
                                                 "Whole Blood: GSE88884" = "GSE88884")
sledaiCorFrame$datasetName<- factor(sledaiCorFrame$datasetName, 
                                    levels=c("Neutrophils: GSE27427", "PBMCs: GSE8650", "Whole Blood: GSE49454", 
                                             "Whole Blood: GSE65391", "Whole Blood: GSE88884", "Summary"))
sleMetaCorPlot <- ggplot(sledaiCorFrame, aes(x=datasetName, middle=sledaiCor, lower=sledaiCor-sledaiSE, upper=sledaiCor+sledaiSE,
                                             ymin=sledaiCor-1.96*sledaiSE, ymax=sledaiCor+1.96*sledaiSE, fill=filterName, color=filterName)) +
  geom_boxplot(stat="identity") +
  scale_x_discrete(limits=rev(levels(sledaiCorFrame$datasetName)))+ scale_y_continuous(limits=c(-0.1,1))+ 
  geom_hline(yintercept=0, lty=2)+coord_flip() + theme(legend.position="none") + xlab("") +ylab("Correlation of SLEDAI and SLE MetaScore")


sledaiCorFrame$gene <- ""


facets=1
confLevel=0.95
ci.value <- -qnorm((1 - confLevel)/2)

pooledMean <- sledaiCorFrame$sledaiCor[6]
pooledSE <- sledaiCorFrame$sledaiSE[6]


studyDataMeans = as.data.table(sledaiCorFrame[,c("datasetName","sledaiCor", "gene")])%>%
  setnames('sledaiCor', 'means')

studyDataSEs = as.data.table(sledaiCorFrame[,c("datasetName","sledaiSE", "gene")]) %>%
  setnames('sledaiSE', 'SEs')

studyData = merge(studyDataMeans, studyDataSEs, by = c('datasetName', "gene")) %>% 
  setnames(c('datasetName'), c('study'))

pooled = data.table(gene = c(""), means = pooledMean, SEs = pooledSE)
pooled$study = 'Summary'
pooled[, cilb := means - ci.value*SEs]
pooled[, ciub := means + ci.value*SEs]
pooled[, RelConf:=1/(ciub-cilb)]

studyData[, ok:=is.finite(means + SEs)]

if (is.null(xlim)) {
  studyData[, xlim.lb := min(means[ok] - ci.value * SEs[ok], na.rm = TRUE)] 
  studyData[, xlim.ub := max(means[ok] + ci.value * SEs[ok], na.rm = TRUE)]
}

studyData[, cilb:=means - ci.value*SEs]
studyData[, ciub:=means + ci.value*SEs]
studyData[, RelConf:=1/((ciub-cilb))]

studyData$study = relevel(studyData$study, ref = 'Summary')

studyData[study == 'Summary', `:=`(means = NA, SEs = NA, ok = FALSE, cilb = NA, ciub = NA, RelConf = NA)]

nStudies = length(unique(studyData$study))

labelstext = c('Summary', as.character(unique(studyData$study)))
labelspos = seq_along(labelstext)-1

# pooled polygons details
pooled_poly = cbind(
  # X VALUES FOR SUMMARY
  pooled[, list(gene, cilb, means, ciub, means)] %>%
    melt(id.vars = 'gene') %>%
    setnames('value', 'x'), 
  # Y VALUES FOR SUMMARY
  pooled[, list(gene, 1.02, 0.85, 1.02, 1.15)] %>%
    melt(id.vars = 'gene') %>%
    setnames('value', 'y'))[,.(gene,x,y)]

sleMetaCorPlot <-  ggplot(studyData, aes(means, study)) + 
  # x = 0 vline
  geom_vline(xintercept = 0.0, linetype=2, alpha=0.3) + 
  # error bars
  geom_errorbarh(alpha=0.75, color="black", height = 0.1, aes(xmax = ciub, xmin = cilb)) + 
  # actual gene boxes
  geom_point(aes(size = RelConf), shape = 15, color = 'cornflowerblue') + 
  # change relative scale of boxes
  scale_size(range = c(4, 12), guide=FALSE) +
  # can play with themes here
  theme(text = element_text(size=16))+
  facet_wrap(~gene, ncol = facets) +
  # This is the summary polygon
  geom_polygon(data = pooled_poly, aes(x = x, y = y), fill = 'coral2') +
  # play with y lims
  coord_cartesian(ylim = c(1.2, nStudies)) + ylab("") + xlab("Correlation of SLEDAI and\nSLE MetaScore")

testingObjectPub$originalData[! names(testingObjectPub$originalData) %in% c("GSE27427", "GSE8650...Complete", "GSE49454", "GSE65391", "GSE88884")] <- NULL
evaluateCorrelation <- function(curEvalFilter, curDataset) {
  curScores <- calculateScore(curEvalFilter, curDataset)
  corRes <- cor.test(curDataset$pheno$sledai, curScores, method="spearman")
  return(data.frame(pVal=corRes$p.value, corVal=corRes$estimate, datasetName = curDataset$formattedName))
}
evaluateCorrelations <- function(curEvalFilter) {
  if(exists("corFrame")) {
    rm(corFrame)
  }
  for(curDatasetName in c("GSE27427", "GSE8650...Complete", "GSE49454", "GSE65391", "GSE88884")) {
    curFrame <- evaluateCorrelation(curEvalFilter, testingObjectPub$originalData[[curDatasetName]])
    if(exists("corFrame")){
      corFrame <- rbind(corFrame, curFrame)
    } else {
      corFrame <- curFrame
    }
  }
  return(corFrame)
} 

numRandomFilters <- 100
for(i in 1:numRandomFilters) {
  randomFilter <- sleFilter
  randomFilter$posGeneNames <- sample(unique(testingObjectPub$originalData$GSE88884$keys), length(randomFilter$posGeneNames))
  randomFilter$negGeneNames <- sample(unique(testingObjectPub$originalData$GSE88884$keys), length(randomFilter$negGeneNames))
  curRandom <- evaluateCorrelations(randomFilter)
  curRandom$iteration <- i
  if(exists("randomFrame")){
    randomFrame <- rbind(randomFrame, curRandom)
  } else {
    randomFrame <- curRandom
  }
}
save(randomFrame, file="RData/randomFrame.RData")

randomFrame$num <- 1:nrow(randomFrame)
randomFrame$iteration <- floor((randomFrame$num-1)/5)

library(dplyr)
randomFrame %>% group_by(datasetName) %>% summarise(meanCor=mean(corVal), meanP = mean(pVal), maxCor= max(corVal), minP = min(pVal))

iterationGrouped <- randomFrame %>% group_by(iteration) %>% 
  summarise(meanCor=mean(corVal), meanP = mean(pVal), maxCor= max(corVal), minP = min(pVal), medianCor = median(corVal))

summary(iterationGrouped)


#######################
# Neutrophil plots
#######################

pdf("plots/neutroPlot.pdf", width=10, height=7)
plot_grid(gse49454neutroplot + sleY, gse65391neutroplot + sleY,  ncol=2, labels="AUTO")
dev.off()
